@@ -3,14 +3,14 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkBioCellularAggregateBase.h,v $
   Language:  C++
-  Date:      $Date: 2006-02-05 20:57:45 $
-  Version:   $Revision: 1.2 $
+  Date:      $Date: 2008-10-20 21:28:20 $
+  Version:   $Revision: 1.4 $
 
-  Copyright (c) 2002 Insight Consortium. All rights reserved.
+  Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
 
-     This software is distributed WITHOUT ANY WARRANTY; without even 
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+     This software is distributed WITHOUT ANY WARRANTY; without even
+     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
@@ -31,17 +31,17 @@ class CellBase;
  * \brief Base class for the CellularAggregates. This base class is not
  * templated over the space dimension.
  */
-class CellularAggregateBase : public itk::Object
+class CellularAggregateBase : public Object
 {
 public:
   /** Standard class typedefs. */
   typedef CellularAggregateBase      Self;
-  typedef itk::Object  Superclass;
-  typedef itk::SmartPointer<Self>        Pointer;
-  typedef itk::SmartPointer<const Self>  ConstPointer;
+  typedef Object                     Superclass;
+  typedef SmartPointer<Self>         Pointer;
+  typedef SmartPointer<const Self>   ConstPointer;
 
   /*** Run-time type information (and related methods). */
-  itkTypeMacro(CellularAggregateBase, itk::Object);
+  itkTypeMacro(BioCellularAggregateBase, Object);
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);  
@@ -61,7 +61,7 @@ protected:
   CellularAggregateBase();
   virtual ~CellularAggregateBase();
   CellularAggregateBase( const Self & );
-  void PrintSelf(std::ostream& os, itk::Indent indent) const;
+  void PrintSelf(std::ostream& os, Indent indent) const;
 
  
 };
@@ -72,4 +72,3 @@ protected:
 
 
 #endif
-
