@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkLevelSetVelocityNeighborhoodExtractor.h,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:28:33 $
-  Version:   $Revision: 1.21 $
+  Date:      $Date: 2008-05-26 11:34:53 $
+  Version:   $Revision: 1.22 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -81,7 +81,7 @@ public:
                       LevelSetType::SetDimension);
 
   /** Index typedef support */
-  typedef Index<itkGetStaticConstMacro(SetDimension)> Index;
+  typedef ::itk::Index<itkGetStaticConstMacro(SetDimension)> Index;
 
   /** AuxVarType typedef support. */
   typedef AuxVarTypeDefault<TAuxValue,VAuxDimension,itkGetStaticConstMacro(SetDimension)> AuxVarType;
