@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMRIBiasFieldCorrectionFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-03-19 04:36:54 $
-  Version:   $Revision: 1.36 $
+  Date:      $Date: 2008-08-04 23:22:58 $
+  Version:   $Revision: 1.37 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -55,7 +55,7 @@ public:
   typedef SmartPointer<const Self>     ConstPointer;
   
   /** Run-time type information (and related methods). */
-  itkTypeMacro( SingleValuedCostFunction, CostFunction );
+  itkTypeMacro( MRIBiasEnergyFunction, SingleValuedCostFunction );
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
