@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkPDEDeformableRegistrationFunction.h,v $
   Language:  C++
-  Date:      $Date: 2005-03-12 01:46:56 $
-  Version:   $Revision: 1.17 $
+  Date:      $Date: 2008-05-22 08:39:42 $
+  Version:   $Revision: 1.20 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -79,15 +79,15 @@ public:
   const FixedImageType * GetFixedImage(void) const
     { return m_FixedImage; }
 
-  /** Set the fixed image. */
+  /** Set the deformation field image. */
   void SetDeformationField(  DeformationFieldTypePointer ptr )
     { m_DeformationField = ptr; }
 
-  /** Get the fixed image. */
-  DeformationFieldTypePointer GetDeformationField(void)
+  /** Get the deformation field. This function should have been
+   *  declared const. It is not for backward compatibility reasons. */
+  DeformationFieldType * GetDeformationField(void)
     { return m_DeformationField; }
 
-
   void SetEnergy( double e) { m_Energy=e;}
   double GetEnergy( ) const { return m_Energy;}
   void SetGradientStep( double e) { m_GradientStep = e;}
@@ -119,17 +119,17 @@ protected:
   };
 
   /** The moving image. */
-  MovingImagePointer                m_MovingImage;
+  MovingImagePointer              m_MovingImage;
   
   /** The fixed image. */
-  FixedImagePointer                   m_FixedImage;
+  FixedImagePointer               m_FixedImage;
 
   /** The deformation field. */
-  DeformationFieldTypePointer                   m_DeformationField;
+  DeformationFieldTypePointer     m_DeformationField;
 
   mutable double                  m_Energy;
   bool                            m_NormalizeGradient;
-  mutable double                          m_GradientStep;
+  mutable double                  m_GradientStep;
 private:
   PDEDeformableRegistrationFunction(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
