@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkCompose2DCovariantVectorImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-09-27 11:36:40 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2008-10-13 18:54:27 $
+  Version:   $Revision: 1.6 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -44,21 +44,21 @@ public:
   Compose2DCovariantVector() {}
   ~Compose2DCovariantVector() {}
   bool operator!=( const Compose2DCovariantVector & ) const
-  {
+    {
     return false;
-  }
+    }
   bool operator==( const Compose2DCovariantVector & other ) const
-  {
+    {
     return !(*this != other);
-  }
+    }
   inline OutputType operator()(  const TInput & s1, 
                                  const TInput & s2 )
-  {
+    {
     OutputType v;
     v[0] = s1;
     v[1] = s2;
     return v;
-  }
+    }
 }; 
 }
 
@@ -75,13 +75,14 @@ BinaryFunctorImageFilter<TInputImage,TInputImage,
 public:
   /** Standard class typedefs. */
   typedef Compose2DCovariantVectorImageFilter  Self;
-  typedef BinaryFunctorImageFilter<TInputImage,TInputImage,
-                                    TOutputImage, 
-                                    Function::Compose2DCovariantVector< 
-    ITK_TYPENAME TInputImage::PixelType > 
-  >  Superclass;
-  typedef SmartPointer<Self>   Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef BinaryFunctorImageFilter<
+    TInputImage,TInputImage,
+    TOutputImage, 
+    Function::Compose2DCovariantVector< 
+      ITK_TYPENAME TInputImage::PixelType > >
+                                               Superclass;
+  typedef SmartPointer<Self>                   Pointer;
+  typedef SmartPointer<const Self>             ConstPointer;
 
   typedef typename Superclass::OutputImageType OutputImageType;
   
