@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkGrayscaleConnectedOpeningImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-10-16 14:22:34 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date: 2008-10-16 16:45:08 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -14,8 +14,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __itkConnectedOpeningImageFilter_h
-#define __itkConnectedOpeningImageFilter_h
+#ifndef __itkGrayscaleConnectedOpeningImageFilter_h
+#define __itkGrayscaleConnectedOpeningImageFilter_h
 
 #include "itkImageToImageFilter.h"
 
@@ -48,18 +48,18 @@ public:
   /** Standard class typedefs. */
   typedef GrayscaleConnectedOpeningImageFilter Self;
   typedef ImageToImageFilter<TInputImage, TOutputImage>
-  Superclass;
-  typedef SmartPointer<Self>        Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+                                               Superclass;
+  typedef SmartPointer<Self>                   Pointer;
+  typedef SmartPointer<const Self>             ConstPointer;
 
   /** Some convenient typedefs. */
-  typedef TInputImage InputImageType;
-  typedef TOutputImage OutputImageType;
+  typedef TInputImage                              InputImageType;
   typedef typename InputImageType::Pointer         InputImagePointer;
   typedef typename InputImageType::ConstPointer    InputImageConstPointer;
   typedef typename InputImageType::RegionType      InputImageRegionType;
   typedef typename InputImageType::PixelType       InputImagePixelType;
   typedef typename InputImageRegionType::IndexType InputImageIndexType;
+  typedef TOutputImage                             OutputImageType;
   typedef typename OutputImageType::Pointer        OutputImagePointer;
   typedef typename OutputImageType::ConstPointer   OutputImageConstPointer;
   typedef typename OutputImageType::RegionType     OutputImageRegionType;
@@ -121,7 +121,7 @@ protected:
   /** GrayscaleConnectedOpeningImageFilter needs the entire input be
    * available. Thus, it needs to provide an implementation of
    * GenerateInputRequestedRegion(). */
-  void GenerateInputRequestedRegion() ;
+  void GenerateInputRequestedRegion();
 
   /** GrayscaleConnectedOpeningImageFilter will produce the entire output. */
   void EnlargeOutputRequestedRegion(DataObject *itkNotUsed(output));
@@ -135,12 +135,12 @@ private:
   GrayscaleConnectedOpeningImageFilter(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
 
-  unsigned long m_NumberOfIterationsUsed;
+  unsigned long       m_NumberOfIterationsUsed;
   InputImageIndexType m_Seed;
 
   bool                m_FullyConnected;
   
-} ; // end of class
+}; // end of class
 
 } // end namespace itk
   
@@ -149,5 +149,3 @@ private:
 #endif
 
 #endif
-
-
