@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMorphologicalGradientImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-03-29 14:53:40 $
-  Version:   $Revision: 1.2 $
+  Date:      $Date: 2008-10-16 19:33:41 $
+  Version:   $Revision: 1.4 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -17,6 +17,16 @@
 #ifndef __itkMorphologicalGradientImageFilter_h
 #define __itkMorphologicalGradientImageFilter_h
 
+// First make sure that the configuration is available.
+// This line can be removed once the optimized versions
+// gets integrated into the main directories.
+#include "itkConfigure.h"
+
+#ifdef ITK_USE_CONSOLIDATED_MORPHOLOGY
+#include "itkOptMorphologicalGradientImageFilter.h"
+#else
+
+
 #include "itkImageToImageFilter.h"
 
 namespace itk {
@@ -52,17 +62,17 @@ public:
   /** Standard class typedefs. */
   typedef MorphologicalGradientImageFilter Self;
   typedef ImageToImageFilter<TInputImage, TOutputImage>
-  Superclass;
-  typedef SmartPointer<Self>        Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+                                           Superclass;
+  typedef SmartPointer<Self>               Pointer;
+  typedef SmartPointer<const Self>         ConstPointer;
 
   /** Some convenient typedefs. */
-  typedef TInputImage InputImageType;
-  typedef TOutputImage OutputImageType;
+  typedef TInputImage                              InputImageType;
   typedef typename InputImageType::Pointer         InputImagePointer;
   typedef typename InputImageType::ConstPointer    InputImageConstPointer;
   typedef typename InputImageType::RegionType      InputImageRegionType;
   typedef typename InputImageType::PixelType       InputImagePixelType;
+  typedef TOutputImage                             OutputImageType;
   typedef typename OutputImageType::Pointer        OutputImagePointer;
   typedef typename OutputImageType::ConstPointer   OutputImageConstPointer;
   typedef typename OutputImageType::RegionType     OutputImageRegionType;
@@ -123,7 +133,7 @@ protected:
    * LargestPossibleRegion for the input, the request is cropped by
    * the LargestPossibleRegion.
    */
-  void GenerateInputRequestedRegion() ;
+  void GenerateInputRequestedRegion();
 
   void GenerateData();
   
@@ -133,8 +143,8 @@ private:
   void operator=(const Self&); //purposely not implemented
 
   /** kernel or structuring element to use. */
-  KernelType m_Kernel ;
-} ; // end of class
+  KernelType m_Kernel;
+}; // end of class
 
 } // end namespace itk
   
@@ -144,4 +154,4 @@ private:
 
 #endif
 
-
+#endif
