@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkNormalVectorDiffusionFunction.h,v $
   Language:  C++
-  Date:      $Date: 2008-03-03 13:58:44 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2008-10-16 19:33:45 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -14,8 +14,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
      =========================================================================*/
-#ifndef __itkNormalVectorDiffusionFunction_h_
-#define __itkNormalVectorDiffusionFunction_h_
+#ifndef __itkNormalVectorDiffusionFunction_h
+#define __itkNormalVectorDiffusionFunction_h
 
 #include "itkNormalVectorFunctionBase.h"
 #include "itkNumericTraits.h"
@@ -60,10 +60,10 @@ class ITK_EXPORT NormalVectorDiffusionFunction
 {
 public:
   /** Standard class typedef. */
-  typedef NormalVectorDiffusionFunction Self;
+  typedef NormalVectorDiffusionFunction               Self;
   typedef NormalVectorFunctionBase <TSparseImageType> Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self> ConstPointer;
+  typedef SmartPointer<Self>                          Pointer;
+  typedef SmartPointer<const Self>                    ConstPointer;
 
   /** Run-time type information (and related methods) */
   itkTypeMacro( NormalVectorDiffusionFunction, NormalVectorFunctionBase);
@@ -75,27 +75,27 @@ public:
   itkNewMacro(Self);
 
   /** Typedefs from the superclass. */
-  typedef typename Superclass::TimeStepType     TimeStepType;
-  typedef typename Superclass::RadiusType       RadiusType;
-  typedef typename Superclass::NeighborhoodType NeighborhoodType;
+  typedef typename Superclass::TimeStepType           TimeStepType;
+  typedef typename Superclass::RadiusType             RadiusType;
+  typedef typename Superclass::NeighborhoodType       NeighborhoodType;
   typedef typename Superclass::NeighborhoodScalesType NeighborhoodScalesType;
-  typedef typename Superclass::FloatOffsetType  FloatOffsetType;
-  typedef typename Superclass::IndexType        IndexType;
-  typedef typename Superclass::SparseImageType  SparseImageType;
-  typedef typename Superclass::NodeType         NodeType;
-  typedef typename Superclass::NodeValueType    NodeValueType;
-  typedef typename Superclass::NormalVectorType NormalVectorType;
+  typedef typename Superclass::FloatOffsetType        FloatOffsetType;
+  typedef typename Superclass::IndexType              IndexType;
+  typedef typename Superclass::SparseImageType        SparseImageType;
+  typedef typename Superclass::NodeType               NodeType;
+  typedef typename Superclass::NodeValueType          NodeValueType;
+  typedef typename Superclass::NormalVectorType       NormalVectorType;
 
   /** This method is used to choose between isotropic/anisotropic filtering. A
       parameter value of 0 indicates isotropic diffusion and is the
       default. Parameter value 1 is anisotropic diffusion. When using
       anisotropic diffusion the conductance parameter should also be set. */
   void SetNormalProcessType( int npt )
-  { m_NormalProcessType = npt; }
+    { m_NormalProcessType = npt; }
 
   /** This method returns the isotropic/anisotropic filtering parameter. */
   int GetNormalProcessType() const 
-  { return m_NormalProcessType; }
+    { return m_NormalProcessType; }
 
   /** This method sets the conductance parameter used in anisotropic
    * filtering. Useful values for processing 2D and 3D shapes are between
@@ -103,21 +103,21 @@ public:
    *  smooth more. As the conductance parameter large, the processing becomes
    *  isotropic. Default is 0. */
   void SetConductanceParameter( NodeValueType cp )
-  {
+    {
     m_ConductanceParameter = cp + static_cast<NodeValueType> (0.001);
     // we add a minimum conductance to avoid divide by zero
     // can make this a parameter.
     m_FluxStopConstant = static_cast<NodeValueType>
       (-1.0/(m_ConductanceParameter*m_ConductanceParameter));
-  }
+    }
 
   /** This method returns the conductance parameter. */
   NodeValueType GetConductanceParameter() const
-  { return m_ConductanceParameter; }
+    { return m_ConductanceParameter; }
 
   /** This method returns the internal variable FluxStopConstant. */
   NodeValueType GetFluxStopConstant() const
-  { return m_FluxStopConstant; }
+    { return m_FluxStopConstant; }
   
   /** This function is called from LevelSetNormalImageFilter for all of the
    *  nodes to compute and store the flux vectors (first derivatives of the
@@ -130,14 +130,6 @@ public:
                                                 void *globalData,
                                                 const FloatOffsetType &offset) const;
   
-private:
-  /** The conductance parameter used for anisotropic diffusion. */
-  NodeValueType m_ConductanceParameter;
-
-  /** The internal variable used in the FluxStopFunction. It is computed from
-   * ConductanceParameter. */
-  NodeValueType m_FluxStopConstant;
-
 protected:
   NormalVectorDiffusionFunction();
   ~NormalVectorDiffusionFunction() {}
@@ -146,13 +138,20 @@ protected:
   /** The method called in anisotropic diffusion to inhibit diffusion across
       areas with large curvature. */
   NodeValueType FluxStopFunction( const NodeValueType v ) const
-  {
+    {
     // the slow ::exp function could be replaced with a lookup table
     if (v<=0.0) return NumericTraits<NodeValueType>::One;
     else return static_cast<NodeValueType>(::exp(m_FluxStopConstant*v));
-  }
+    }
   
 private:
+  /** The conductance parameter used for anisotropic diffusion. */
+  NodeValueType m_ConductanceParameter;
+
+  /** The internal variable used in the FluxStopFunction. It is computed from
+   * ConductanceParameter. */
+  NodeValueType m_FluxStopConstant;
+
   /** The isotropic/anisotropic filtering choice parameter. */
   int m_NormalProcessType; 
 
