@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkOrImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-09-27 11:36:41 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2008-10-14 19:56:22 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -52,17 +52,17 @@ public:
   OR() {};
   ~OR() {};
   bool operator!=( const OR & ) const
-  {
+    {
     return false;
-  }
+    }
   bool operator==( const OR & other ) const
-  {
+    {
     return !(*this != other);
-  }
+    }
   inline TOutput operator()( const TInput1 & A, const TInput2 & B)
-  {
+    {
     return static_cast<TOutput>( A | B );
-  }
+    }
 }; 
 
 }
@@ -79,14 +79,14 @@ BinaryFunctorImageFilter<TInputImage1,TInputImage2,TOutputImage,
 {
 public:
   /** Standard class typedefs. */
-  typedef OrImageFilter  Self;
-  typedef BinaryFunctorImageFilter<TInputImage1,TInputImage2,TOutputImage, 
-                                   Functor::OR< 
-    typename TInputImage1::PixelType, 
-    typename TInputImage2::PixelType,
-    typename TOutputImage::PixelType>   
-  >  Superclass;
-  typedef SmartPointer<Self>   Pointer;
+  typedef OrImageFilter             Self;
+  typedef BinaryFunctorImageFilter<
+    TInputImage1,TInputImage2,TOutputImage, 
+    Functor::OR<typename TInputImage1::PixelType, 
+                typename TInputImage2::PixelType,
+                typename TOutputImage::PixelType> >
+                                    Superclass;
+  typedef SmartPointer<Self>        Pointer;
   typedef SmartPointer<const Self>  ConstPointer;
 
   /** Method for creation through the object factory. */
