@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkPointSetToImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2005-07-27 15:21:11 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2008-12-08 01:10:42 $
+  Version:   $Revision: 1.4.2.1 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -53,7 +53,7 @@ public:
   typedef typename Superclass::OutputImageRegionType OutputImageRegionType;
 
   /** Some convenient typedefs. */
-  typedef TInputPointSet InputPointSetType;
+  typedef TInputPointSet                             InputPointSetType;
   typedef typename InputPointSetType::Pointer        InputPointSetPointer;
   typedef typename InputPointSetType::ConstPointer   InputPointSetConstPointer;
 
@@ -64,8 +64,9 @@ public:
                       TOutputImage::ImageDimension);
 
   /** Image spacing and origin typedefs */
-  typedef typename TOutputImage::SpacingType SpacingType;
-  typedef typename TOutputImage::PointType   PointType;
+  typedef typename TOutputImage::SpacingType        SpacingType;
+  typedef typename TOutputImage::DirectionType      DirectionType;
+  typedef typename TOutputImage::PointType          PointType;
 
   /** Set/Get the input point-set of this process object.  */
   virtual void SetInput( const InputPointSetType *pointset);
@@ -87,6 +88,12 @@ public:
    * For ImageBase and Image, the default data spacing is unity. */
   itkGetConstReferenceMacro(Spacing,SpacingType);
 
+  /** Get/Set the direction of the image. The
+   * direction is the relationship of the grid to physical
+   * coordinates. */
+  itkSetMacro(Direction,DirectionType);
+  itkGetConstReferenceMacro(Direction,DirectionType);
+
   /** Set the origin of the image. The origin is the geometric
    * coordinates of the image origin.  It is stored internally
    * as double but may be set from float.
@@ -130,11 +137,12 @@ protected:
   virtual void GenerateOutputInformation(){}; // do nothing
   virtual void GenerateData();
 
-  SizeType     m_Size;
-  SpacingType  m_Spacing;
-  PointType    m_Origin;
-  ValueType    m_InsideValue;
-  ValueType    m_OutsideValue;
+  SizeType            m_Size;
+  PointType           m_Origin;
+  SpacingType         m_Spacing;
+  DirectionType       m_Direction;
+  ValueType           m_InsideValue;
+  ValueType           m_OutsideValue;
 
   virtual void PrintSelf(std::ostream& os, Indent indent) const;
 
