@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkResampleImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2008-01-04 16:51:26 $
-  Version:   $Revision: 1.55 $
+  Date:      $Date: 2008-10-24 16:30:43 $
+  Version:   $Revision: 1.58 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -106,9 +106,7 @@ public:
                       TInputImage::ImageDimension);
 
 
-  /** Transform typedef.
-   *
-   **/
+  /** Transform typedef. */
   typedef Transform<TInterpolatorPrecisionType, 
     itkGetStaticConstMacro(ImageDimension), 
     itkGetStaticConstMacro(ImageDimension)> TransformType;
@@ -174,7 +172,7 @@ public:
   itkSetMacro( DefaultPixelValue, PixelType );
 
   /** Get the pixel value when a transformed pixel is outside of the image */
-  itkGetMacro( DefaultPixelValue, PixelType );
+  itkGetConstReferenceMacro( DefaultPixelValue, PixelType );
 
   /** Set the output image spacing. */
   itkSetMacro( OutputSpacing, SpacingType );
@@ -203,6 +201,15 @@ public:
     this->SetSize ( Image->GetLargestPossibleRegion().GetSize() );
     }
 
+  /** Helper method to set the output parameters based on this image */
+  void SetOutputParametersFromConstImage ( typename OutputImageType::ConstPointer Image )
+    {
+    this->SetOutputOrigin ( Image->GetOrigin() );
+    this->SetOutputSpacing ( Image->GetSpacing() );
+    this->SetOutputDirection ( Image->GetDirection() );
+    this->SetSize ( Image->GetLargestPossibleRegion().GetSize() );
+    }
+
   /** Set the start index of the output largest possible region. 
    * The default is an index of all zeros. */
   itkSetMacro( OutputStartIndex, IndexType );
@@ -314,4 +321,3 @@ private:
 #endif
   
 #endif
-
