@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkSparseFieldLayer.h,v $
   Language:  C++
-  Date:      $Date: 2004-12-21 22:47:31 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2008-10-18 16:11:13 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -31,45 +31,45 @@ namespace itk {
 template <class TNodeType>
 class ConstSparseFieldLayerIterator
 {
- public:
+public:
   const TNodeType& operator*() const
-  { return *m_Pointer; }
+    { return *m_Pointer; }
 
   const TNodeType* operator->() const
-  { return m_Pointer; }
+    { return m_Pointer; }
 
   const TNodeType* GetPointer() const
-  { return m_Pointer; }
+    { return m_Pointer; }
   
   bool operator==(const ConstSparseFieldLayerIterator o) const
-  {
+    {
     if (m_Pointer == o.m_Pointer) return true;
     else return false;
-  }
+    }
 
   bool operator!=(const ConstSparseFieldLayerIterator o) const
-  {
+    {
     if (m_Pointer != o.m_Pointer) return true;
     else return false;
-  }
+    }
 
   ConstSparseFieldLayerIterator &operator++()
-  {
+    {
     m_Pointer = m_Pointer->Next;
     return *this;
-  }
+    }
 
   ConstSparseFieldLayerIterator &operator--()
-  {
+    {
     m_Pointer = m_Pointer->Previous;
     return *this;
-  }
+    }
 
   ConstSparseFieldLayerIterator()
-  { m_Pointer=0; }
+    { m_Pointer=0; }
 
   ConstSparseFieldLayerIterator(TNodeType *p)
-  { m_Pointer=p; }
+    { m_Pointer=p; }
 
   ~ConstSparseFieldLayerIterator() {}
 
@@ -88,42 +88,42 @@ public:
   typedef ConstSparseFieldLayerIterator<TNodeType> Superclass;
 
   SparseFieldLayerIterator() : Superclass()
-  { }
+    {}
 
   SparseFieldLayerIterator(TNodeType *p) : Superclass(p)
-  { }
+    {}
 
   TNodeType &operator*()
-  { return *this->m_Pointer; }
+    { return *this->m_Pointer; }
 
   TNodeType* operator->()
-  { return this->m_Pointer; }
+    { return this->m_Pointer; }
 
   TNodeType* GetPointer()
-  { return this->m_Pointer; }
+    { return this->m_Pointer; }
   
   SparseFieldLayerIterator &operator++()
-  {
+    {
     this->m_Pointer = this->m_Pointer->Next;
     return *this;
-  }
+    }
 
   SparseFieldLayerIterator &operator--()
-  {
+    {
     this->m_Pointer = this->m_Pointer->Previous;
     return *this;
-  }
+    }
 
   SparseFieldLayerIterator &operator=(Superclass &sc)
-  {
+    {
     this->m_Pointer = const_cast<TNodeType*> (sc.GetPointer());
     return *this;
-  }
+    }
 };
 
 
 /** \class itkSparseFieldLayer
- *      
+ *
  *  \par
  *  This class implements a *very* simple linked list that is used to manage
  *  nodes in a layer of a sparse field level-set solver.  For more information
@@ -148,9 +148,9 @@ class ITK_EXPORT SparseFieldLayer
 {
 public:
   /** Standard typedefs. */
-  typedef SparseFieldLayer Self;
-  typedef Object  Superclass;
-  typedef SmartPointer<Self>  Pointer;
+  typedef SparseFieldLayer          Self;
+  typedef Object                    Superclass;
+  typedef SmartPointer<Self>        Pointer;
   typedef SmartPointer<const Self>  ConstPointer;
 
   /** Method for creation through the object factory. */
@@ -169,75 +169,77 @@ public:
   /** Iterator type for the list. */
   typedef SparseFieldLayerIterator<NodeType> Iterator;
 
-  /** Const iterator type for the list.*/
+  /** Const iterator type for the list. */
   typedef ConstSparseFieldLayerIterator<NodeType> ConstIterator;
 
   /** Regions used for multithreading */
   struct RegionType 
-  {
+    {
     ConstIterator first;
     ConstIterator last;  // this is one past the actual last element
-  };   
+    };   
   
   typedef std::vector<RegionType> RegionListType;
 
-  /** Returns a pointer to the first node in the list.  Constant time.*/ 
+  /** Returns a pointer to the first node in the list.  Constant
+   * time. */ 
   NodeType *Front()
-  { return m_HeadNode->Next; }
+    { return m_HeadNode->Next; }
 
   /** Returns a const pointer to the first node in the list. Constant time. */
   const NodeType *Front() const
-  { return m_HeadNode->Next; }
+    { return m_HeadNode->Next; }
 
   /** Unlinks the first node from the list. Constant time. */
   void PopFront()
-  {
+    {
     m_HeadNode->Next = m_HeadNode->Next->Next;
     m_HeadNode->Next->Previous = m_HeadNode;
     m_Size -= 1;
-  }
+    }
   
   /** Links a node into the front of the list. Constant time. */
   void PushFront(NodeType *n)
-  {
+    {
     n->Next = m_HeadNode->Next;
     n->Previous = m_HeadNode;
     m_HeadNode->Next->Previous = n;
     m_HeadNode->Next = n;
     m_Size += 1;
-  }
+    }
   
   /** Unlinks a node from the list */
   void Unlink(NodeType *n)
-  {
+    {
     n->Previous->Next = n->Next;
     n->Next->Previous = n->Previous;
     m_Size -= 1;
-  }
+    }
   
   /** Returns an iterator pointing to the first node in the list. */
   Iterator Begin()
-  { return Iterator(m_HeadNode->Next); }
+    { return Iterator(m_HeadNode->Next); }
 
-  /** Returns a const iterator pointing to the first node in the list.*/
+  /** Returns a const iterator pointing to the first node in the
+   * list. */
   ConstIterator Begin() const
-  { return ConstIterator(m_HeadNode->Next); }
+    { return ConstIterator(m_HeadNode->Next); }
 
-  /** Returns an iterator pointing one node past the end of the list.*/
+  /** Returns an iterator pointing one node past the end of the list. */
   Iterator End()
-  { return Iterator(m_HeadNode); }
+    { return Iterator(m_HeadNode); }
 
   /** Returns a const iterator pointing one node past the end of the list. */
   ConstIterator End() const
-  { return ConstIterator(m_HeadNode); }
+    { return ConstIterator(m_HeadNode); }
   
   /** Returns TRUE if the list is empty, FALSE otherwise. Executes in constant
    *  time. */
   bool Empty() const
-  {
+    {
     if (m_HeadNode->Next == m_HeadNode) return true;
     else return false;
-  }
+    }
   
   /** Returns the number of elements in the list. Size() executes in constant
    *  time. */
@@ -247,10 +249,6 @@ public:
       the itkSparseFieldLayer */
   RegionListType SplitRegions(int num) const;
 
-  /** Splices the contents of another SparseFieldLayer into this one, combining
-      the two lists.*/
-  //  void Splice (SparseFieldLayer &);
-  
 protected:
   SparseFieldLayer();
   ~SparseFieldLayer();
@@ -262,7 +260,7 @@ private:
   
   /** The anchor node of the list.  m_HeadNode->Next is the first node in the
    *  list. If m_HeadNode->Next == m_HeadNode, then the list is empty. */
-  NodeType *m_HeadNode;
+  NodeType *   m_HeadNode;
   unsigned int m_Size;
 };
 
