@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkWarpVectorImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-04-04 13:13:52 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2008-10-07 17:31:02 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -59,10 +59,12 @@ namespace itk
  * Position mapped to outside of the input image buffer are assigned
  * a edge padding value.
  *
- * The LargetPossibleRegion for the output is inherited from the 
- * input deformation field. The output image spacing and origin may be set 
- * via SetOutputSpacing, SetOutputOrigin. The default are respectively a 
- * vector of 1's and a vector of 0's.
+ * The LargetPossibleRegion for the output is inherited
+ * from the input deformation field. The output image
+ * spacing, origin and direction may be set via
+ * SetOutputSpacing, SetOutputOrigin and
+ * SetOutputDirection. The default are respectively a
+ * vector of 1's, a vector of 0's and an identity matrix.
  *
  * This class is templated over the type of the input image, the
  * type of the output image and the type of the deformation field.
@@ -89,10 +91,10 @@ class ITK_EXPORT WarpVectorImageFilter :
 {
 public:
   /** Standard class typedefs. */
-  typedef WarpVectorImageFilter      Self;
+  typedef WarpVectorImageFilter                        Self;
   typedef ImageToImageFilter<TInputImage,TOutputImage> Superclass;
-  typedef SmartPointer<Self>         Pointer;
-  typedef SmartPointer<const Self>   ConstPointer;
+  typedef SmartPointer<Self>                           Pointer;
+  typedef SmartPointer<const Self>                     ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -104,16 +106,17 @@ public:
   typedef typename TOutputImage::RegionType OutputImageRegionType;
 
   /** Inherit some types from the superclass. */
-  typedef typename Superclass::InputImageType        InputImageType;
-  typedef typename Superclass::InputImagePointer     InputImagePointer;
-  typedef typename Superclass::OutputImageType       OutputImageType;
-  typedef typename Superclass::OutputImagePointer    OutputImagePointer;
+  typedef typename Superclass::InputImageType         InputImageType;
+  typedef typename Superclass::InputImagePointer      InputImagePointer;
+  typedef typename Superclass::OutputImageType        OutputImageType;
+  typedef typename Superclass::OutputImagePointer     OutputImagePointer;
   typedef typename Superclass::InputImageConstPointer InputImageConstPointer;
-  typedef typename OutputImageType::IndexType        IndexType;
-  typedef typename OutputImageType::SizeType         SizeType;
-  typedef typename OutputImageType::PixelType        PixelType;
-  typedef typename OutputImageType::SpacingType      SpacingType;
-  typedef typename OutputImageType::PixelType::ValueType        ValueType;
+
+  typedef typename OutputImageType::IndexType            IndexType;
+  typedef typename OutputImageType::SizeType             SizeType;
+  typedef typename OutputImageType::PixelType            PixelType;
+  typedef typename OutputImageType::SpacingType          SpacingType;
+  typedef typename OutputImageType::PixelType::ValueType ValueType;
 
   /** Determine the image dimension. */
   itkStaticConstMacro(ImageDimension, unsigned int,
@@ -124,8 +127,8 @@ public:
                       PixelType::Dimension );
 
   /** Deformation field typedef support. */
-  typedef TDeformationField    DeformationFieldType;
-  typedef typename DeformationFieldType::Pointer  DeformationFieldPointer;
+  typedef TDeformationField                        DeformationFieldType;
+  typedef typename DeformationFieldType::Pointer   DeformationFieldPointer;
   typedef typename DeformationFieldType::PixelType DisplacementType;
 
   /** Interpolator typedef support. */
@@ -138,6 +141,9 @@ public:
   /** Point type */
   typedef Point<CoordRepType,itkGetStaticConstMacro(ImageDimension)> PointType;
 
+  /** Type for representing the direction of the output image */
+  typedef typename TOutputImage::DirectionType     DirectionType;
+
   /** Set the deformation field. */
   void SetDeformationField( DeformationFieldType * field );
 
@@ -164,6 +170,10 @@ public:
   /** Get the output image origin. */
   itkGetConstReferenceMacro(OutputOrigin, PointType);
 
+  /** Set/Get the direction (orientation) of the output image */
+  itkSetMacro(OutputDirection, DirectionType );
+  itkGetConstReferenceMacro(OutputDirection, DirectionType );
+
   /** Set the edge padding value */
   itkSetMacro( EdgePaddingValue, PixelType );
 
@@ -218,6 +228,7 @@ private:
   PixelType                  m_EdgePaddingValue;
   SpacingType                m_OutputSpacing;
   PointType                  m_OutputOrigin;
+  DirectionType              m_OutputDirection;
 
   InterpolatorPointer        m_Interpolator;
   
