@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkFiniteDifferenceSparseImageFunction.h,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:29:07 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2008-10-16 23:25:41 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -14,8 +14,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __itkFiniteDifferenceSparseImageFunction_h_
-#define __itkFiniteDifferenceSparseImageFunction_h_
+#ifndef __itkFiniteDifferenceSparseImageFunction_h
+#define __itkFiniteDifferenceSparseImageFunction_h
 
 #include "itkFiniteDifferenceFunction.h"
 
@@ -47,10 +47,10 @@ class ITK_EXPORT FiniteDifferenceSparseImageFunction
 {
 public:
   /** Standard class typedef. */
-  typedef FiniteDifferenceSparseImageFunction Self;
-  typedef FiniteDifferenceFunction<TSparseImageType> Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self> ConstPointer;
+  typedef FiniteDifferenceSparseImageFunction           Self;
+  typedef FiniteDifferenceFunction<TSparseImageType>    Superclass;
+  typedef SmartPointer<Self>                            Pointer;
+  typedef SmartPointer<const Self>                      ConstPointer;
 
   /** Run-time type information (and related methods) */
   itkTypeMacro( FiniteDifferenceSparseImageFunction, FiniteDifferenceFunction );
@@ -82,9 +82,9 @@ public:
   virtual PixelType ComputeUpdate(const NeighborhoodType&,
                                   void*,
                                   const FloatOffsetType&)
-  {
+    {
     return static_cast<PixelType>(0);
-  }
+    }
 
   /** The update called from the FiniteDifferenceSparseImageFilter. This
       function replaces the ComputeUpdate function. */
