@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkFixedArray.h,v $
   Language:  C++
-  Date:      $Date: 2006-04-20 14:54:09 $
-  Version:   $Revision: 1.38 $
+  Date:      $Date: 2008-10-16 13:28:49 $
+  Version:   $Revision: 1.42 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -82,42 +82,44 @@ public:
   /** A const iterator through the array. */
   typedef const ValueType*  ConstIterator;
 
-  /** \brief A reverse iterator through the array. */
+  /** \class ReverseIterator 
+   * \brief A reverse iterator through the array. */
   class ReverseIterator
-  {
-  public:
-    explicit ReverseIterator(Iterator i): m_Iterator(i) {}
-    Iterator operator++()        { return --m_Iterator; }
-    Iterator operator++(int)     { return m_Iterator--; }
-    Iterator operator--()        { return ++m_Iterator; }
-    Iterator operator--(int)     { return m_Iterator++; }
-    Iterator operator->() const  { return (m_Iterator-1); }
-    ValueType& operator*() const { return *(m_Iterator-1); }
-    bool operator!=(const ReverseIterator &rit) const {return m_Iterator != rit.m_Iterator;};
-    bool operator==(const ReverseIterator &rit) const {return m_Iterator == rit.m_Iterator;};
-  private:
-    Iterator m_Iterator;
-  };
+    {
+    public:
+      explicit ReverseIterator(Iterator i): m_Iterator(i) {}
+      Iterator operator++()        { return --m_Iterator; }
+      Iterator operator++(int)     { return m_Iterator--; }
+      Iterator operator--()        { return ++m_Iterator; }
+      Iterator operator--(int)     { return m_Iterator++; }
+      Iterator operator->() const  { return (m_Iterator-1); }
+      ValueType& operator*() const { return *(m_Iterator-1); }
+      bool operator!=(const ReverseIterator &rit) const {return m_Iterator != rit.m_Iterator;}
+      bool operator==(const ReverseIterator &rit) const {return m_Iterator == rit.m_Iterator;}
+    private:
+      Iterator m_Iterator;
+    };
   
-  /** \brief A const reverse iterator through the array. */
+  /** \class ConstReverseIterator 
+   * \brief A const reverse iterator through the array. */
   class ConstReverseIterator
-  {
-  public:
-    explicit ConstReverseIterator(ConstIterator i): m_Iterator(i) {}
-    ConstIterator operator++()         { return --m_Iterator; }
-    ConstIterator operator++(int)      { return m_Iterator--; }
-    ConstIterator operator--()         { return ++m_Iterator; }
-    ConstIterator operator--(int)      { return m_Iterator++; }
-    ConstIterator operator->() const   { return (m_Iterator-1); }
-    const ValueType& operator*() const { return *(m_Iterator-1); }
-    bool operator!=(const ConstReverseIterator &rit) const {return m_Iterator != rit.m_Iterator;};
-    bool operator==(const ConstReverseIterator &rit) const {return m_Iterator == rit.m_Iterator;};
-  private:
-    ConstIterator m_Iterator;
-  };  
+    {
+    public:
+      explicit ConstReverseIterator(ConstIterator i): m_Iterator(i) {}
+      ConstIterator operator++()         { return --m_Iterator; }
+      ConstIterator operator++(int)      { return m_Iterator--; }
+      ConstIterator operator--()         { return ++m_Iterator; }
+      ConstIterator operator--(int)      { return m_Iterator++; }
+      ConstIterator operator->() const   { return (m_Iterator-1); }
+      const ValueType& operator*() const { return *(m_Iterator-1); }
+      bool operator!=(const ConstReverseIterator &rit) const {return m_Iterator != rit.m_Iterator;}
+      bool operator==(const ConstReverseIterator &rit) const {return m_Iterator == rit.m_Iterator;}
+    private:
+      ConstIterator m_Iterator;
+    };  
   
   /** A pointer to the ValueType. */
-  typedef ValueType*        pointer;
+  typedef ValueType *        pointer;
 
   /** A const pointer to the ValueType. */
   typedef const ValueType*  const_pointer;
@@ -140,23 +142,38 @@ public:
   FixedArray(const FixedArray< TFixedArrayValueType, VLength >& r)
     {
     typename FixedArray< TFixedArrayValueType, VLength >::ConstIterator input = r.Begin();
-    for(Iterator i = this->Begin() ; i != this->End() ;) 
+    Iterator i = this->Begin();
+    while( i != this->End() ) 
+      {
       *i++ = static_cast< TValueType >(*input++);
+      }
     }
   
 
   /** This destructor is not virtual for performance reasons. However, this
-   * means that subclasses cannot allocate memory. */
-  ~FixedArray();
-  
+   * means that subclasses cannot allocate memory.
+   *
+   * The destructor is PURPOSELY NOT DEFINED, in order to prevent inefficient
+   * byte alignment of arrays of this object.
+   *
+   * ~FixedArray();
+   *
+   * For a full discussion, see 
+   * http://www.itk.org/mailman/private/insight-developers/2008-June/010480.html
+   *
+   */
+
   /** Operator= defined for a variety of types. */
   template< class TFixedArrayValueType >
   FixedArray& operator= (const FixedArray< TFixedArrayValueType, VLength > & r)
     {
     if((void *)r.Begin() == (void *)m_InternalArray) return *this;
     typename FixedArray< TFixedArrayValueType, VLength >::ConstIterator input = r.Begin();
-    for(Iterator i = this->Begin() ; i != this->End() ;) 
+    Iterator i = this->Begin();
+    while( i != this->End() ) 
+      {
       *i++ = static_cast< TValueType >(*input++);
+      }
     return *this;
     }
 
@@ -240,4 +257,6 @@ std::ostream & operator<<(std::ostream &os, const FixedArray<TValueType,VLength>
 # include "itkFixedArray.txx"
 #endif
 
+#include "itkNumericTraitsFixedArrayPixel.h"
+
 #endif
