@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkImageBase.h,v $
   Language:  C++
-  Date:      $Date: 2007-10-21 18:03:05 $
-  Version:   $Revision: 1.69 $
+  Date:      $Date: 2008-11-01 15:28:00 $
+  Version:   $Revision: 1.75 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -12,8 +12,8 @@
   Portions of this code are covered under the VTK copyright.
   See VTKCopyright.txt or http://www.kitware.com/VTKCopyright.htm for details.
 
-     This software is distributed WITHOUT ANY WARRANTY; without even 
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+     This software is distributed WITHOUT ANY WARRANTY; without even
+     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
@@ -31,11 +31,16 @@
 #include "itkFixedArray.h"
 #include "itkPoint.h"
 #include "itkMatrix.h"
+#include "itkContinuousIndex.h"
 #include "itkImageHelper.h"
 #include <vnl/vnl_matrix_fixed.txx>
 
 #include "itkImageRegion.h"
 
+#ifdef ITK_USE_TEMPLATE_META_PROGRAMMING_LOOP_UNROLLING
+#include "itkImageTransformHelper.h"
+#endif
+
 namespace itk
 {
 
@@ -49,8 +54,8 @@ template <typename TImage>
 struct GetImageDimension
 {
   itkStaticConstMacro(ImageDimension, unsigned int, TImage::ImageDimension);
-}; 
-  
+};
+
 /** \class ImageBase
  * \brief Base class for templated image classes.
  *
@@ -62,14 +67,14 @@ struct GetImageDimension
  * subclasses of ImageBase, namely Image and ImageAdaptor.
  *
  * There are three sets of meta-data describing an image. These are "Region"
- * objects that define a portion of an image via a starting index for the 
- * image array and a size. The ivar LargestPossibleRegion defines the size 
+ * objects that define a portion of an image via a starting index for the
+ * image array and a size. The ivar LargestPossibleRegion defines the size
  * and starting index of the image dataset. The entire image dataset, however,
  * may not be resident in memory. The region of the image that is resident in
  * memory is defined by the "BufferedRegion". The Buffer is a contiguous block
  * of memory.  The third set of meta-data defines a region of interest, called
  * the "RequestedRegion". The RequestedRegion is used by the pipeline
- * execution model to define what a filter is requested to produce. 
+ * execution model to define what a filter is requested to produce.
  *
  * [RegionIndex, RegionSize] C [BufferIndex, BufferSize]
  *                           C [ImageIndex, ImageSize]
@@ -83,11 +88,11 @@ class ITK_EXPORT ImageBase : public DataObject
 {
 public:
   /** Standard typedefs. */
-  typedef ImageBase           Self;
-  typedef DataObject  Superclass;
-  typedef SmartPointer<Self>  Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
-  
+  typedef ImageBase                     Self;
+  typedef DataObject                    Superclass;
+  typedef SmartPointer<Self>            Pointer;
+  typedef SmartPointer<const Self>      ConstPointer;
+
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
 
@@ -101,26 +106,26 @@ public:
   itkStaticConstMacro(ImageDimension, unsigned int, VImageDimension );
 
   /** Index typedef support. An index is used to access pixel values. */
-  typedef Index<VImageDimension>  IndexType;
-  typedef typename IndexType::IndexValueType  IndexValueType;
-  
+  typedef Index<VImageDimension>                  IndexType;
+  typedef typename IndexType::IndexValueType      IndexValueType;
+
   /** Offset typedef support. An offset represent relative position
    * between indices. */
-  typedef Offset<VImageDimension>  OffsetType;
-  typedef typename OffsetType::OffsetValueType OffsetValueType;
+  typedef Offset<VImageDimension>                 OffsetType;
+  typedef typename OffsetType::OffsetValueType    OffsetValueType;
 
   /** Size typedef support. A size is used to define region bounds. */
-  typedef Size<VImageDimension>  SizeType;
-  typedef typename SizeType::SizeValueType SizeValueType;
-    
+  typedef Size<VImageDimension>                   SizeType;
+  typedef typename SizeType::SizeValueType        SizeValueType;
+
   /** Region typedef support. A region is used to specify a subset of an image. */
-  typedef ImageRegion<VImageDimension>  RegionType;
+  typedef ImageRegion<VImageDimension>            RegionType;
 
   /** Spacing typedef support.  Spacing holds the size of a pixel.  The
    * spacing is the geometric distance between image samples. ITK only
    * supports positive spacing value: negative values may cause
-   * undesirable results.*/
-  typedef Vector<double, VImageDimension> SpacingType;
+   * undesirable results.  */
+  typedef Vector<double, VImageDimension>         SpacingType;
 
   /** Origin typedef support.  The origin is the geometric coordinates
    * of the index (0,0). */
@@ -135,7 +140,7 @@ public:
   void Initialize();
 
   /** Image dimension. The dimension of an image is fixed at construction. */
-  static unsigned int GetImageDimension() 
+  static unsigned int GetImageDimension()
     { return VImageDimension; }
 
   /** Set the origin of the image. The origin is the geometric
@@ -148,10 +153,10 @@ public:
 
   /** Set the direction cosines of the image. The direction cosines
    * are vectors that point from one pixel to the next.
-   * 
+   *
    * One row of the matrix indicates the direction cosines of the unit vector
    * that is parallel to the lines of the image grid corresponding to that
-   * dimension. For example, and image with Direction matrix 
+   * dimension. For example, and image with Direction matrix
    *
    *    0.866   0.500
    *   -0.500   0.866
@@ -179,14 +184,6 @@ public:
    * For ImageBase and Image, the default direction is identity. */
   itkGetConstReferenceMacro(Direction, DirectionType);
 
-  /** Set the spacing (size of a pixel) of the image. The
-   * spacing is the geometric distance between image samples.
-   * It is stored internally as double, but may be set from
-   * float. \sa GetSpacing() */
-  itkSetMacro(Spacing, SpacingType);
-  virtual void SetSpacing( const double spacing[VImageDimension] );
-  virtual void SetSpacing( const float spacing[VImageDimension] );
-
   /** Get the spacing (size of a pixel) `of the image. The
    * spacing is the geometric distance between image samples.
    * The value returned is a pointer to a double array.
@@ -195,7 +192,7 @@ public:
 
   /** Get the origin of the image. The origin is the geometric
    * coordinates of the index (0,0).  The value returned is a pointer
-   * to a double array.  For ImageBase and Image, the default origin is 
+   * to a double array.  For ImageBase and Image, the default origin is
    * 0. */
   itkGetConstReferenceMacro(Origin, PointType);
 
@@ -217,16 +214,16 @@ public:
     { return m_LargestPossibleRegion;};
 
   /** Set the region object that defines the size and starting index
-   * of the region of the image currently loaded in memory. 
+   * of the region of the image currently loaded in memory.
    * \sa ImageRegion, SetLargestPossibleRegion(), SetRequestedRegion() */
   virtual void SetBufferedRegion(const RegionType &region);
 
   /** Get the region object that defines the size and starting index
-   * of the region of the image currently loaded in memory. 
+   * of the region of the image currently loaded in memory.
    * \sa ImageRegion, SetLargestPossibleRegion(), SetRequestedRegion() */
   virtual const RegionType& GetBufferedRegion() const
   { return m_BufferedRegion;};
-  
+
   /** Set the region object that defines the size and starting index
    * for the region of the image requested (i.e., the region of the
    * image to be operated on by a filter). Setting the RequestedRegion
@@ -237,7 +234,7 @@ public:
   virtual void SetRequestedRegion(const RegionType &region);
 
   /** Set the requested region from this data object to match the requested
-   * region of the data object passed in as a parameter.  This method 
+   * region of the data object passed in as a parameter.  This method
    * implements the API from DataObject. The data object parameter must be
    * castable to an ImageBase. Setting the RequestedRegion does not cause
    * the object to be modified. This method is called internally by
@@ -263,7 +260,7 @@ public:
    * some data accessing algorithms. The entries in the offset table
    * are only valid after the BufferedRegion is set. */
   const OffsetValueType *GetOffsetTable() const { return m_OffsetTable; };
-  
+
   /** Compute an offset from the beginning of the buffer for a pixel
    * at the specified index. The index is not checked as to whether it
    * is inside the current buffer, so the computed offset could
@@ -272,23 +269,23 @@ public:
    * prior to calling ComputeOffset. */
 
 
-#if 1
+#ifdef ITK_USE_TEMPLATE_META_PROGRAMMING_LOOP_UNROLLING
   inline OffsetValueType ComputeOffset(const IndexType &ind) const
-  {
+    {
     OffsetValueType offset = 0;
     ImageHelper<VImageDimension,VImageDimension>::ComputeOffset(this->GetBufferedRegion().GetIndex(),
                                                                 ind,
                                                                 m_OffsetTable,
                                                                 offset);
     return offset;
-  }
+    }
 #else
   OffsetValueType ComputeOffset(const IndexType &ind) const
-  {
+    {
     // need to add bounds checking for the region/buffer?
     OffsetValueType offset=0;
     const IndexType &bufferedRegionIndex = this->GetBufferedRegion().GetIndex();
-  
+
     // data is arranged as [][][][slice][row][col]
     // with Index[0] = col, Index[1] = row, Index[2] = slice
     for (int i=VImageDimension-1; i > 0; i--)
@@ -297,8 +294,8 @@ public:
       }
     offset += (ind[0] - bufferedRegionIndex[0]);
 
-    return offset;    
-  }
+    return offset;
+    }
 #endif
   /** Compute the index of the pixel at a specified offset from the
    * beginning of the buffered region. Bounds checking is not
@@ -307,9 +304,9 @@ public:
    * should be between 0 and the number of pixels in the
    * BufferedRegion (the latter can be found using
    * ImageRegion::GetNumberOfPixels()). */
-#if 1
+#ifdef ITK_USE_TEMPLATE_META_PROGRAMMING_LOOP_UNROLLING
   inline IndexType ComputeIndex(OffsetValueType offset) const
-  {
+    {
     IndexType index;
     const IndexType &bufferedRegionIndex = this->GetBufferedRegion().GetIndex();
     ImageHelper<VImageDimension,VImageDimension>::ComputeIndex(bufferedRegionIndex,
@@ -317,13 +314,13 @@ public:
                                                                m_OffsetTable,
                                                                index);
     return index;
-  }
+    }
 #else
   IndexType ComputeIndex(OffsetValueType offset) const
-  {
+    {
     IndexType index;
     const IndexType &bufferedRegionIndex = this->GetBufferedRegion().GetIndex();
-    
+
     for (int i=VImageDimension-1; i > 0; i--)
       {
       index[i] = static_cast<IndexValueType>(offset / m_OffsetTable[i]);
@@ -332,10 +329,186 @@ public:
       }
     index[0] = bufferedRegionIndex[0] + static_cast<IndexValueType>(offset);
 
-    return index;    
-  }
+    return index;
+    }
 #endif
 
+  /** Set the spacing (size of a pixel) of the image. The
+   * spacing is the geometric distance between image samples.
+   * It is stored internally as double, but may be set from
+   * float. These methods also pre-compute the Index to Physical
+   * point transforms of the image.
+   * \sa GetSpacing() */
+  virtual void SetSpacing (const SpacingType & spacing);
+  virtual void SetSpacing (const double spacing[VImageDimension]);
+  virtual void SetSpacing (const float spacing[VImageDimension]);
+
+
+  /** Get the index (discrete) from a physical point.
+   * Floating point index results are truncated to integers.
+   * Returns true if the resulting index is within the image, false otherwise
+   * \sa Transform */
+#ifdef ITK_USE_TEMPLATE_META_PROGRAMMING_LOOP_UNROLLING
+  template<class TCoordRep>
+  bool TransformPhysicalPointToIndex(
+    const Point<TCoordRep, VImageDimension>& point,
+    IndexType & index ) const
+    {
+      ImageTransformHelper<VImageDimension,VImageDimension-1,VImageDimension-1>::TransformPhysicalPointToIndex(
+        this->m_PhysicalPointToIndex, this->m_Origin, point, index);
+
+    // Now, check to see if the index is within allowed bounds
+    const bool isInside = this->GetLargestPossibleRegion().IsInside( index );
+    return isInside;
+    }
+#else
+  template<class TCoordRep>
+  bool TransformPhysicalPointToIndex(
+            const Point<TCoordRep, VImageDimension>& point,
+            IndexType & index                                ) const
+    {
+    for (unsigned int i = 0; i < VImageDimension; i++)
+      {
+      TCoordRep sum = NumericTraits<TCoordRep>::Zero;
+      for (unsigned int j = 0; j < VImageDimension; j++)
+        {
+        sum += this->m_PhysicalPointToIndex[i][j] * (point[j] - this->m_Origin[j]);
+        }
+      index[i] = static_cast< IndexValueType>( sum );
+      }
+
+    // Now, check to see if the index is within allowed bounds
+    const bool isInside = this->GetLargestPossibleRegion().IsInside( index );
+
+    return isInside;
+    }
+#endif
+
+  /** \brief Get the continuous index from a physical point
+   *
+   * Returns true if the resulting index is within the image, false otherwise.
+   * \sa Transform */
+  template<class TCoordRep>
+  bool TransformPhysicalPointToContinuousIndex(
+              const Point<TCoordRep, VImageDimension>& point,
+              ContinuousIndex<TCoordRep, VImageDimension>& index   ) const
+    {
+    Vector<double, VImageDimension> cvector;
+
+    for( unsigned int k = 0; k < VImageDimension; k++ )
+      {
+      cvector[k] = point[k] - this->m_Origin[k];
+      }
+    cvector = m_PhysicalPointToIndex * cvector;
+    for( unsigned int i = 0; i < VImageDimension; i++ )
+      {
+      index[i] = static_cast<TCoordRep>(cvector[i]);
+      }
+
+    // Now, check to see if the index is within allowed bounds
+    const bool isInside = this->GetLargestPossibleRegion().IsInside( index );
+
+    return isInside;
+    }
+
+
+  /** Get a physical point (in the space which
+   * the origin and spacing infomation comes from)
+   * from a continuous index (in the index space)
+   * \sa Transform */
+  template<class TCoordRep>
+  void TransformContinuousIndexToPhysicalPoint(
+            const ContinuousIndex<TCoordRep, VImageDimension>& index,
+            Point<TCoordRep, VImageDimension>& point        ) const
+    {
+    for( unsigned int r=0; r<VImageDimension; r++)
+      {
+      TCoordRep sum = NumericTraits<TCoordRep>::Zero;
+      for( unsigned int c=0; c<VImageDimension; c++ )
+        {
+        sum += this->m_IndexToPhysicalPoint(r,c) * index[c];
+        }
+      point[r] = sum + this->m_Origin[r];
+      }
+    }
+
+  /** Get a physical point (in the space which
+   * the origin and spacing infomation comes from)
+   * from a discrete index (in the index space)
+   *
+   * \sa Transform */
+#ifdef ITK_USE_TEMPLATE_META_PROGRAMMING_LOOP_UNROLLING
+  template<class TCoordRep>
+  void TransformIndexToPhysicalPoint(
+                      const IndexType & index,
+                      Point<TCoordRep, VImageDimension>& point ) const
+    {
+      ImageTransformHelper<VImageDimension,VImageDimension-1,VImageDimension-1>::TransformIndexToPhysicalPoint(
+        this->m_IndexToPhysicalPoint, this->m_Origin, index, point);
+    }
+#else
+  template<class TCoordRep>
+  void TransformIndexToPhysicalPoint(
+                      const IndexType & index,
+                      Point<TCoordRep, VImageDimension>& point ) const
+    {
+    for (unsigned int i = 0; i < VImageDimension; i++)
+      {
+      point[i] = this->m_Origin[i];
+      for (unsigned int j = 0; j < VImageDimension; j++)
+        {
+        point[i] += m_IndexToPhysicalPoint[i][j] * index[j];
+        }
+      }
+    }
+#endif
+
+
+  /** Get a physical point (in the space which
+   * the origin and spacing infomation comes from)
+   * from a discrete index (in the index space)
+   *
+   * \sa Transform */
+
+  /** Take a vector or covariant vector that has been computed in the
+   * coordinate system parallel to the image grid and rotate it by the
+   * direction cosines in order to get it in terms of the coordinate system of
+   * the image acquisition device.  This implementation in the OrientedImage
+   * multiply the array (vector or covariant vector) by the matrix of Direction
+   * Cosines. The arguments of the method are of type FixedArray to make
+   * possible to use this method with both Vector and CovariantVector.
+   * The Method is implemented differently in the itk::Image.
+   *
+   * \sa Image
+   */ 
+  template<class TCoordRep>
+  void TransformLocalVectorToPhysicalVector(
+    const FixedArray<TCoordRep, VImageDimension> & inputGradient,
+          FixedArray<TCoordRep, VImageDimension> & outputGradient ) const
+    {
+    //
+    // This temporary implementation should be replaced with Template MetaProgramming.
+    // 
+#ifdef ITK_USE_ORIENTED_IMAGE_DIRECTION
+    const DirectionType & direction = this->GetDirection();
+    for (unsigned int i = 0; i < VImageDimension; i++)
+      {
+      typedef typename NumericTraits<TCoordRep>::AccumulateType CoordSumType;
+      CoordSumType sum = NumericTraits<CoordSumType>::Zero;
+      for (unsigned int j = 0; j < VImageDimension; j++)
+        {
+        sum += direction[i][j] * inputGradient[j];
+        }
+      outputGradient[i] = static_cast<TCoordRep>( sum );
+      }
+#else
+    for (unsigned int i = 0; i < VImageDimension; i++)
+      {
+      outputGradient[i] = inputGradient[i];
+      }
+#endif
+    }
+
   /** Copy information from the specified data set.  This method is
    * part of the pipeline execution model. By default, a ProcessObject
    * will copy meta-data from the first input to all of its
@@ -393,7 +566,7 @@ public:
    * throws a InvalidRequestedRegionError exception is the requested
    * region is not within the LargestPossibleRegion. */
   virtual bool VerifyRequestedRegion();
-  
+
   /** INTERNAL This method is used internally by filters to copy meta-data from
    * the output to the input. Users should not have a need to use this method.
    *
@@ -406,12 +579,12 @@ public:
    * \endcode
    *
    * \sa ImageBase, VectorImage
-   * 
-   * Returns/Sets the number of components in the image. Note that for all 
+   *
+   * Returns/Sets the number of components in the image. Note that for all
    * images this is 1. Even for Image< RGBPixel< T >, 3 >.
    * This is >= 1 only for time-series images such as itk::VectorImage. */
   virtual unsigned int GetNumberOfComponentsPerPixel() const;
-  virtual void SetNumberOfComponentsPerPixel( unsigned int ); 
+  virtual void SetNumberOfComponentsPerPixel( unsigned int );
 
 protected:
   ImageBase();
@@ -424,13 +597,25 @@ protected:
    * the BufferedRegion is set. */
   void ComputeOffsetTable();
 
+  /** Compute helper matrices used to transform Index coordinates to
+   * PhysicalPoint coordinates and back. This method is virtual and will be
+   * overloaded in derived classes in order to provide backward compatibility
+   * behavior in classes that did not used to take image orientation into
+   * account.  */ 
+  virtual void ComputeIndexToPhysicalPointMatrices();
+
 protected:
   /** Origin and spacing of physical coordinates. This variables are
    * protected for efficiency.  They are referenced frequently by
    * inner loop calculations. */
-  SpacingType  m_Spacing;
-  PointType   m_Origin;
-  DirectionType m_Direction;
+  SpacingType         m_Spacing;
+  PointType           m_Origin;
+  DirectionType       m_Direction;
+
+  /** Matrices intended to help with the conversion of Index coordinates
+   *  to PhysicalPoint coordinates */
+  DirectionType       m_IndexToPhysicalPoint;
+  DirectionType       m_PhysicalPointToIndex;
 
 private:
   ImageBase(const Self&); //purposely not implemented
@@ -441,6 +626,7 @@ private:
   RegionType          m_LargestPossibleRegion;
   RegionType          m_RequestedRegion;
   RegionType          m_BufferedRegion;
+
 };
 
 } // end namespace itk
