@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkLandmarkBasedTransformInitializer.h,v $
   Language:  C++
-  Date:      $Date: 2007-10-16 14:22:35 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2008-06-26 13:50:49 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -134,13 +134,13 @@ public:
 
     
   /** Set the Fixed landmark point containers */
-  void SetFixedLandmarks(LandmarkPointContainer & fixedLandmarks)
+  void SetFixedLandmarks(const LandmarkPointContainer & fixedLandmarks)
     {
     this->m_FixedLandmarks = fixedLandmarks;
     } 
   
   /** Set the Moving landmark point containers */
-  void SetMovingLandmarks(LandmarkPointContainer & movingLandmarks)
+  void SetMovingLandmarks(const LandmarkPointContainer & movingLandmarks)
     {
     this->m_MovingLandmarks = movingLandmarks;
     }
