@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkLightObject.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-11-08 19:55:45 $
-  Version:   $Revision: 1.36 $
+  Date:      $Date: 2008-05-20 22:03:27 $
+  Version:   $Revision: 1.40 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -30,11 +30,34 @@
 #ifdef GCC_USEDEMANGLE
 #include <cstdlib>
 #include <cxxabi.h>
-#endif 
+#endif
+
+#if defined(__APPLE__)
+  // OSAtomic.h optimizations only used in 10.5 and later
+  #if MAC_OS_X_VERSION_MAX_ALLOWED >= 1050
+    #include <libkern/OSAtomic.h>
+  #endif
+
+#elif defined(__GLIBCPP__) || defined(__GLIBCXX__)
+  #if (__GNUC__ > 4) || ((__GNUC__ == 4) && (__GNUC_MINOR__ >= 2))
+  # include <ext/atomicity.h>
+  #else
+  # include <bits/atomicity.h>
+  #endif
+
+#endif
+
 
 namespace itk
 {
 
+#if defined(__GLIBCXX__) // g++ 3.4+
+
+using __gnu_cxx::__atomic_add;
+using __gnu_cxx::__exchange_and_add;
+
+#endif
+
 LightObject::Pointer
 LightObject::New()
 {
@@ -136,9 +159,28 @@ void
 LightObject
 ::Register() const
 {
+  // Windows optimization
+#if (defined(WIN32) || defined(_WIN32))
+  InterlockedIncrement(&m_ReferenceCount);
+
+// Mac optimization
+#elif defined(__APPLE__) && (MAC_OS_X_VERSION_MIN_REQUIRED >= 1050)
+ #if defined (__LP64__) && __LP64__
+  OSAtomicIncrement64Barrier(&m_ReferenceCount);
+ #else
+  OSAtomicIncrement32Barrier(&m_ReferenceCount);
+ #endif
+
+// gcc optimization
+#elif defined(__GLIBCPP__) || defined(__GLIBCXX__)
+  __atomic_add(&m_ReferenceCount, 1);
+
+// General case
+#else
   m_ReferenceCountLock.Lock();
   m_ReferenceCount++;
   m_ReferenceCountLock.Unlock();
+#endif
 }
 
 
@@ -149,16 +191,48 @@ void
 LightObject
 ::UnRegister() const
 {
+  // As ReferenceCount gets unlocked, we may have a race condition
+  // to delete the object.
+   
+  // Windows optimization
+#if (defined(WIN32) || defined(_WIN32))
+  if ( InterlockedDecrement(&m_ReferenceCount) <= 0 )
+    {
+    delete this;
+    }
+
+// Mac optimization
+#elif defined(__APPLE__) && (MAC_OS_X_VERSION_MIN_REQUIRED >= 1050)
+ #if defined (__LP64__) && __LP64__
+  if ( OSAtomicDecrement64Barrier(&m_ReferenceCount) <= 0 )
+    {
+    delete this;
+    }
+ #else
+  if ( OSAtomicDecrement32Barrier(&m_ReferenceCount) <= 0 )
+    {
+    delete this;
+    }
+ #endif
+
+// gcc optimization
+#elif defined(__GLIBCPP__) || defined(__GLIBCXX__)
+  if ( __exchange_and_add(&m_ReferenceCount, -1) <= 1 )
+    {
+    delete this;
+    }
+
+// General case
+#else
   m_ReferenceCountLock.Lock();
-  int tmpReferenceCount = --m_ReferenceCount;
+  InternalReferenceCountType tmpReferenceCount = --m_ReferenceCount;
   m_ReferenceCountLock.Unlock();
   
-  // ReferenceCount in now unlocked.  We may have a race condition
-  // to delete the object.
   if ( tmpReferenceCount <= 0)
     {
     delete this;
     }
+#endif
 }
 
 
@@ -170,7 +244,7 @@ LightObject
 ::SetReferenceCount(int ref)
 {
   m_ReferenceCountLock.Lock();
-  m_ReferenceCount = ref;
+  m_ReferenceCount = static_cast<InternalReferenceCountType>(ref);
   m_ReferenceCountLock.Unlock();
 
   if ( ref <= 0)
