@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkLightObject.h,v $
   Language:  C++
-  Date:      $Date: 2007-08-22 12:56:44 $
-  Version:   $Revision: 1.35 $
+  Date:      $Date: 2008-05-20 22:03:31 $
+  Version:   $Revision: 1.41 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -26,6 +26,14 @@
 #include <iostream>
 #include <typeinfo>
 
+#if defined(_WIN32)
+  // To get LONG defined
+  #include "itkWindows.h"
+#elif defined(__APPLE__)
+  // To get MAC_OS_X_VERSION_MIN_REQUIRED defined
+  #include <AvailabilityMacros.h>
+#endif
+
 namespace itk
 {
   
@@ -95,7 +103,7 @@ public:
 
   /** Gets the reference count on this object. */
   virtual int GetReferenceCount() const 
-    {return m_ReferenceCount;}
+    {return static_cast<int>(m_ReferenceCount);}
 
   /** Sets the reference count on this object. This is a dangerous
    * method, use it with care. */
@@ -112,9 +120,25 @@ protected:
   virtual void PrintSelf(std::ostream& os, Indent indent) const;
   virtual void PrintHeader(std::ostream& os, Indent indent) const;
   virtual void PrintTrailer(std::ostream& os, Indent indent) const;
+
+  /** Define the type of the reference count according to the
+      target. This allows the use of atomic operations */
+#if (defined(WIN32) || defined(_WIN32))
+  typedef LONG InternalReferenceCountType;
+#elif defined(__APPLE__) && (MAC_OS_X_VERSION_MIN_REQUIRED >= 1050)
+ #if defined (__LP64__) && __LP64__
+  typedef volatile int64_t InternalReferenceCountType;
+ #else
+  typedef volatile int32_t InternalReferenceCountType;
+ #endif
+#elif defined(__GLIBCPP__) || defined(__GLIBCXX__)
+  typedef _Atomic_word InternalReferenceCountType;
+#else
+  typedef int InternalReferenceCountType;
+#endif
   
   /** Number of uses of this object by other objects. */
-  mutable volatile int m_ReferenceCount;
+  mutable InternalReferenceCountType m_ReferenceCount;
 
   /** Mutex lock to protect modification to the reference count */
   mutable SimpleFastMutexLock m_ReferenceCountLock;
