@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkLinearInterpolateImageFunction.h,v $
   Language:  C++
-  Date:      $Date: 2008-01-06 23:12:49 $
-  Version:   $Revision: 1.33 $
+  Date:      $Date: 2008-05-13 15:32:37 $
+  Version:   $Revision: 1.34 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -48,7 +48,7 @@ namespace itk
  *
  * \ingroup ImageFunctions ImageInterpolators 
  */
-template <class TInputImage, class TCoordRep = float>
+template <class TInputImage, class TCoordRep = double>
 class ITK_EXPORT LinearInterpolateImageFunction : 
   public InterpolateImageFunction<TInputImage,TCoordRep> 
 {
