@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkLogger.h,v $
   Language:  C++
-  Date:      $Date: 2006-02-05 20:57:46 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2008-05-08 15:40:08 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -56,6 +56,10 @@ protected:
   /** Destructor */
   virtual ~Logger() {};
 
+private:
+  Logger(const Self&); //purposely not implemented
+  void operator=(const Self&); //purposely not implemented
+
 };  // class Logger
 
 } // namespace itk
