@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMacro.h,v $
   Language:  C++
-  Date:      $Date: 2007-12-28 18:28:29 $
-  Version:   $Revision: 1.83 $
+  Date:      $Date: 2008-07-31 12:08:03 $
+  Version:   $Revision: 1.88 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -34,6 +34,7 @@
 #include "itkConfigure.h"
 
 #include <string>
+#include <cstdlib>
 
 // Determine type of string stream to use.
 #if !defined(CMAKE_NO_ANSI_STRING_STREAM)
@@ -482,7 +483,7 @@ extern ITKCommon_EXPORT void OutputWindowDisplayDebugText(const char*);
 /** This macro is used to print debug (or other information). They are
  * also used to catch errors, etc. Example usage looks like:
  * itkDebugMacro(<< "this is debug info" << this->SomeVariable); */
-#if defined(ITK_LEAN_AND_MEAN) || defined(__BORLANDC__)
+#if defined(ITK_LEAN_AND_MEAN) || defined(__BORLANDC__) || defined(NDEBUG)
 #define itkDebugMacro(x)
 #else
 #define itkDebugMacro(x) \
@@ -695,17 +696,65 @@ private:
 #if defined(ITK_LEGACY_REMOVE) || defined(ITK_LEGACY_SILENT)
 # define itkLegacyBodyMacro(method, version)
 # define itkLegacyReplaceBodyMacro(method, version, replace)
+# define itkGenericLegacyBodyMacro(method, version)
+# define itkGenericLegacyReplaceBodyMacro(method, version, replace)
 #else
 # define itkLegacyBodyMacro(method, version) \
   itkWarningMacro(#method " was deprecated for ITK " #version " and will be removed in a future version.")
 # define itkLegacyReplaceBodyMacro(method, version, replace) \
   itkWarningMacro(#method " was deprecated for ITK " #version " and will be removed in a future version.  Use " #replace " instead.")
+# define itkGenericLegacyBodyMacro(method, version) \
+  itkGenericOutputMacro(#method " was deprecated for ITK " #version " and will be removed in a future version.")
+# define itkGenericLegacyReplaceBodyMacro(method, version, replace) \
+  itkGenericOutputMacro(#method " was deprecated for ITK " #version " and will be removed in a future version.  Use " #replace " instead.")
 #endif
 
 #if defined(__INTEL_COMPILER)
 # pragma warning (disable: 193) /* #if testing undefined identifier */
 #endif
 
+//=============================================================================
+/* Define a common way of declaring a templated function as a friend inside a class.
+  - ITK_FRIEND_TEMPLATE_FUNCTION_ARGUMENTS(T) 
+
+  The following templated function 
+
+            template <T>
+            T add(const T & a, const T & b);
+
+  is declared as friend in some compilers as:
+
+            class A
+              {
+              public:
+                friend Self add<Self>( const Self & a, const Self & b );
+              }
+
+   while other compilers will do
+
+            class A
+              {
+              public:
+                friend Self add<>( const Self & a, const Self & b );
+              }
+
+   This characteristic of the compiler is checked by a TRY_COMPILE
+   command defined in Insight/CMake/itkTestFriendTemplatedFunction.cxx
+
+*/
+#if defined(ITK_SUPPORTS_TEMPLATED_FRIEND_FUNCTION_WITH_NULL_STRING)
+#define ITK_FRIEND_TEMPLATE_FUNCTION_ARGUMENT(T)
+#else
+#if defined(ITK_SUPPORTS_TEMPLATED_FRIEND_FUNCTION_WITH_EMPTY_BRACKETS)
+#define ITK_FRIEND_TEMPLATE_FUNCTION_ARGUMENT(T)  <>
+#else
+#if defined(ITK_SUPPORTS_TEMPLATED_FRIEND_FUNCTION_WITH_TEMPLATE_ARGUMENTS)
+#define ITK_FRIEND_TEMPLATE_FUNCTION_ARGUMENT(T)  <T>
+#endif
+#endif
+#endif
+
+
 //=============================================================================
 /* Choose a way to prevent template instantiation on this platform.
   - ITK_TEMPLATE_DO_NOT_INSTANTIATE = use #pragma do_not_instantiate to
