@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMaximumRatioDecisionRule.h,v $
   Language:  C++
-  Date:      $Date: 2007-12-23 17:59:28 $
-  Version:   $Revision: 1.9 $
+  Date:      $Date: 2008-05-08 15:40:08 $
+  Version:   $Revision: 1.10 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -87,6 +87,9 @@ protected:
   virtual ~MaximumRatioDecisionRule() {}
   
 private:
+  MaximumRatioDecisionRule(const Self&); //purposely not implemented
+  void operator=(const Self&); //purposely not implemented
+
   /** Number of classes */
   APrioriVectorSizeType m_NumberOfClasses ;
 
