@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMultiThreader.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-09-16 15:24:14 $
-  Version:   $Revision: 1.40 $
+  Date:      $Date: 2008-05-26 00:24:36 $
+  Version:   $Revision: 1.44 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -20,11 +20,16 @@
 
 #include "itkMultiThreader.h"
 #include "itkObjectFactory.h"
+#include "itksys/SystemTools.hxx"
+#include <vcl_cstdlib.h>
+
 #ifndef _WIN32
 #include <unistd.h>
 #endif
-#ifdef _WIN32
+#ifdef _MSC_VER
 #pragma warning ( disable : 4786 )
+#endif
+#ifdef _WIN32
 #include "itkWindows.h"
 #include <process.h>
 #endif
@@ -78,7 +83,24 @@ void MultiThreader::SetGlobalDefaultNumberOfThreads(int val)
 
 int MultiThreader::GetGlobalDefaultNumberOfThreads()
 {
-  if (m_GlobalDefaultNumberOfThreads == 0)
+  // if default number has been set then don't try to update it; just
+  // return the value
+  if (m_GlobalDefaultNumberOfThreads != 0)
+    {
+    return m_GlobalDefaultNumberOfThreads;
+    }
+
+  // first, check for enviornment variable
+  itksys_stl::string itkGlobalDefaultNumberOfThreadsEnv = "0";
+  if (itksys::SystemTools::GetEnv("ITK_GLOBAL_DEFAULT_NUMBER_OF_THREADS",
+                                  itkGlobalDefaultNumberOfThreadsEnv))
+    {
+    m_GlobalDefaultNumberOfThreads = 
+      atoi(itkGlobalDefaultNumberOfThreadsEnv.c_str());
+    }
+
+  // otherwise, set number of threads based on system information
+  if (m_GlobalDefaultNumberOfThreads <= 0)
     {
     int num;
 #ifdef ITK_USE_SPROC
@@ -121,25 +143,27 @@ int MultiThreader::GetGlobalDefaultNumberOfThreads()
 #endif
 
 #ifdef __APPLE__
-    // Use sysctl() to determine the number of CPUs.  This is prefered
+    // Determine the number of CPU cores. Prefer sysctlbyname()
     // over MPProcessors() because it doesn't require CoreServices
-    // (which is only available in 32bit on Mac OS X 10.4)
-    int mib[2] = {CTL_HW, HW_NCPU};
+    // (which is only available in 32bit on Mac OS X 10.4).
+    // hw.logicalcpu takes into account cores/CPUs that are
+    // disabled because of power management.
     size_t dataLen = sizeof(int); // 'num' is an 'int'
-    int result = sysctl(mib, 2, &num, &dataLen, NULL, 0);
+    int result = sysctlbyname ("hw.logicalcpu", &num, &dataLen, NULL, 0);
     if (result == -1)
       {
       num = 1;
       }
 #endif
 
-    // Limit the number of threads
-    if (num > ITK_MAX_THREADS)
-      {
-      num = ITK_MAX_THREADS;
-      }
     m_GlobalDefaultNumberOfThreads = num;
     }
+
+  // limit the number of threads to ITK_MAX_THREADS
+  if (m_GlobalDefaultNumberOfThreads > ITK_MAX_THREADS)
+    {
+    m_GlobalDefaultNumberOfThreads = ITK_MAX_THREADS;
+    }
   
   return m_GlobalDefaultNumberOfThreads;
 }
@@ -238,7 +262,7 @@ void MultiThreader::SetMultipleMethod( int index, ThreadFunctionType f, void *da
 // Execute the method set as the SingleMethod on NumberOfThreads threads.
 void MultiThreader::SingleMethodExecute()
 {
-  int thread_loop;
+  int thread_loop = 0;
   ThreadProcessIDType process_id[ITK_MAX_THREADS];
   
   if ( !m_SingleMethod)
@@ -646,7 +670,6 @@ int MultiThreader::SpawnThread( ThreadFunctionType f, void *UserData )
   if ( id >= ITK_MAX_THREADS )
     {
     itkExceptionMacro( << "You have too many active threads!" );
-    return -1;
     }
   
   m_SpawnedThreadInfoArray[id].UserData        = UserData;
