@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMultipleLogOutput.h,v $
   Language:  C++
-  Date:      $Date: 2006-02-05 20:57:46 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2008-05-08 15:40:09 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -82,6 +82,8 @@ protected:
   virtual ~MultipleLogOutput();
 
 private:
+  MultipleLogOutput(const Self&); //purposely not implemented
+  void operator=(const Self&); //purposely not implemented
   
   typedef std::set< OutputType::Pointer >   ContainerType;
 
