@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkNeighborhood.h,v $
   Language:  C++
-  Date:      $Date: 2007-02-07 13:52:48 $
-  Version:   $Revision: 1.43 $
+  Date:      $Date: 2008-05-26 00:29:28 $
+  Version:   $Revision: 1.44 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -73,11 +73,11 @@ public:
   typedef typename AllocatorType::const_iterator ConstIterator;
   
   /** Size and value typedef support. */
-  typedef Size<VDimension> SizeType;
+  typedef ::itk::Size<VDimension> SizeType;
   typedef typename SizeType::SizeValueType SizeValueType;
   
   /** Radius typedef support. */
-  typedef Size<VDimension> RadiusType;
+  typedef ::itk::Size<VDimension> RadiusType;
 
   /** Offset type used to reference neighbor locations */
   typedef Offset<VDimension> OffsetType;
