@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkSmartPointer.h,v $
   Language:  C++
-  Date:      $Date: 2006-03-06 15:07:34 $
-  Version:   $Revision: 1.38 $
+  Date:      $Date: 2008-05-16 20:15:32 $
+  Version:   $Revision: 1.39 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -17,7 +17,6 @@
 #ifndef __itkSmartPointer_h
 #define __itkSmartPointer_h
 
-#include "itkMacro.h"
 #include <iostream>
 
 namespace itk
@@ -40,7 +39,7 @@ namespace itk
  * \ingroup DataAccess
  */
 template <class TObjectType>
-class ITK_EXPORT SmartPointer 
+class SmartPointer 
 {
 public:
   typedef TObjectType ObjectType;
