@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkTestMain.h,v $
   Language:  C++
-  Date:      $Date: 2008-03-17 19:28:02 $
-  Version:   $Revision: 1.27 $
+  Date:      $Date: 2008-10-24 16:21:55 $
+  Version:   $Revision: 1.31 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -75,12 +75,13 @@ void PrintAvailableTests()
 
 int main(int ac, char* av[] )
 {
-  char *baselineFilename = NULL;
-  char *testFilename = NULL;
   double intensityTolerance  = 2.0;
   unsigned int numberOfPixelsTolerance = 0;
   unsigned int radiusTolerance = 0;
 
+  typedef std::pair< char *, char *> ComparePairType;
+  std::vector< ComparePairType > compareList;
+
   RegisterTests();
   std::string testToRun;
   if(ac < 2)
@@ -105,47 +106,50 @@ int main(int ac, char* av[] )
     }
   else
     {
-    if (strcmp(av[1], "--with-threads") == 0)
+    while( ac > 0 && testToRun.empty() )
       {
-      int numThreads = atoi(av[2]);
-      itk::MultiThreader::SetGlobalDefaultNumberOfThreads(numThreads);
-      av += 2;
-      ac -= 2;
-      }
-    else if (strcmp(av[1], "--without-threads") == 0)
-      {
-      itk::MultiThreader::SetGlobalDefaultNumberOfThreads(1);
-      av += 1;
-      ac -= 1;
-      }
-    if (ac > 3 && strcmp(av[1], "--compare") == 0)
-      {
-      baselineFilename = av[2];
-      testFilename = av[3];
-      av += 3;
-      ac -= 3;
-      // Advanced options for image comparison (The options must appear in 
-      // this order in the command line because this parser code is not that smart)
-      if (ac > 2 && strcmp(av[1], "--compareNumberOfPixelsTolerance") == 0)
+      if (strcmp(av[1], "--with-threads") == 0)
+        {
+        int numThreads = atoi(av[2]);
+        itk::MultiThreader::SetGlobalDefaultNumberOfThreads(numThreads);
+        av += 2;
+        ac -= 2;
+        }
+      else if (strcmp(av[1], "--without-threads") == 0)
+        {
+        itk::MultiThreader::SetGlobalDefaultNumberOfThreads(1);
+        av += 1;
+        ac -= 1;
+        }
+      else if (ac > 3 && strcmp(av[1], "--compare") == 0)
+        {
+        compareList.push_back( ComparePairType( av[2], av[3] ) );
+        av += 3;
+        ac -= 3;
+        }
+      else if (ac > 2 && strcmp(av[1], "--compareNumberOfPixelsTolerance") == 0)
         {
         numberOfPixelsTolerance = atoi( av[2] );
         av += 2;
         ac -= 2;
         }
-      if (ac > 2 && strcmp(av[1], "--compareRadiusTolerance") == 0)
+      else if (ac > 2 && strcmp(av[1], "--compareRadiusTolerance") == 0)
         {
         radiusTolerance = atoi( av[2] );
         av += 2;
         ac -= 2;
         }
-      if (ac > 2 && strcmp(av[1], "--compareIntensityTolerance") == 0)
+      else if (ac > 2 && strcmp(av[1], "--compareIntensityTolerance") == 0)
         {
         intensityTolerance = atof( av[2] );
         av += 2;
         ac -= 2;
         }
+      else
+        {
+        testToRun = av[1];
+        }
       }
-    testToRun = av[1];
     }
   std::map<std::string, MainFuncPointer>::iterator j = StringToTestFunctionMap.find(testToRun);
   if(j != StringToTestFunctionMap.end())
@@ -158,8 +162,10 @@ int main(int ac, char* av[] )
       result = (*f)(ac-1, av+1);
 
       // Make a list of possible baselines
-      if (baselineFilename && testFilename)
+      for( int i=0; i<static_cast<int>(compareList.size()); i++)
         {
+        char * baselineFilename = compareList[i].first;
+        char * testFilename = compareList[i].second;
         std::map<std::string,int> baselines = RegressionTestBaselines(baselineFilename);
         std::map<std::string,int>::iterator baseline = baselines.begin();
         std::string bestBaseline;
@@ -205,8 +211,7 @@ int main(int ac, char* av[] )
     catch(const itk::ExceptionObject& e)
       {
       std::cerr << "ITK test driver caught an ITK exception:\n";
-      std::cerr << e.GetFile() << ":" << e.GetLine() << ":\n"
-                << e.GetDescription() << "\n";
+      e.Print(std::cerr);
       result = -1;
       }
     catch(const std::exception& e)
@@ -293,7 +298,8 @@ int RegressionTestImage (const char *testImageFilename,
     diff->SetToleranceRadius( radiusTolerance );
     diff->UpdateLargestPossibleRegion();
 
-  double status = diff->GetNumberOfPixelsWithDifferences();
+    unsigned long status = 0;
+    status = diff->GetNumberOfPixelsWithDifferences();
 
   // if there are discrepencies, create an diff image
   if ( (status > numberOfPixelsTolerance) && reportErrors )
