@@ -3,8 +3,8 @@
 Program:   Insight Segmentation & Registration Toolkit
 Module:    $RCSfile: itkTransformFactoryBase.cxx,v $
 Language:  C++
-Date:      $Date: 2007-03-27 11:04:05 $
-Version:   $Revision: 1.3 $
+Date:      $Date: 2008-07-03 13:38:44 $
+Version:   $Revision: 1.6 $
 
 Copyright (c) Insight Software Consortium. All rights reserved.
 See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -19,11 +19,13 @@ PURPOSE.  See the above copyright notices for more information.
 #include "itkVersion.h"
 
 #include "itkAffineTransform.h"
+#include "itkBSplineDeformableTransform.h"
 #include "itkCenteredAffineTransform.h"
 #include "itkCenteredEuler3DTransform.h"
 #include "itkCenteredEuler3DTransform.h"
 #include "itkCenteredRigid2DTransform.h"
 #include "itkCenteredSimilarity2DTransform.h"
+#include "itkSimilarity2DTransform.h"
 #include "itkEuler2DTransform.h"
 #include "itkEuler3DTransform.h"
 #include "itkFixedCenterOfRotationAffineTransform.h"
@@ -62,11 +64,14 @@ void TransformFactoryBase::RegisterDefaultTransforms()
     // BSpline purposely not registered!
     TransformFactory<AffineTransform<double,2> >::RegisterTransform ();
     TransformFactory<AffineTransform<double,3> >::RegisterTransform ();
+    TransformFactory<BSplineDeformableTransform<double,2,2> >::RegisterTransform ();
+    TransformFactory<BSplineDeformableTransform<double,3,3> >::RegisterTransform ();
     TransformFactory<CenteredAffineTransform<double,2> >::RegisterTransform ();
     TransformFactory<CenteredAffineTransform<double,3> >::RegisterTransform ();
     TransformFactory<CenteredEuler3DTransform<double> >::RegisterTransform ();
-    TransformFactory<CenteredRigid2DTransform < float > >::RegisterTransform();
+    TransformFactory<CenteredRigid2DTransform < double > >::RegisterTransform();
     TransformFactory<CenteredSimilarity2DTransform<double> >::RegisterTransform ();
+    TransformFactory<Similarity2DTransform<double> >::RegisterTransform ();
     TransformFactory<Euler2DTransform<double> >::RegisterTransform ();
     TransformFactory<Euler3DTransform<double> >::RegisterTransform ();
     TransformFactory<FixedCenterOfRotationAffineTransform<double> >::RegisterTransform ();
@@ -88,10 +93,14 @@ void TransformFactoryBase::RegisterDefaultTransforms()
 
     TransformFactory<AffineTransform<float,2> >::RegisterTransform ();
     TransformFactory<AffineTransform<float,3> >::RegisterTransform ();
+    TransformFactory<BSplineDeformableTransform<float,2,2> >::RegisterTransform ();
+    TransformFactory<BSplineDeformableTransform<float,3,3> >::RegisterTransform ();
     TransformFactory<CenteredAffineTransform<float,2> >::RegisterTransform ();
     TransformFactory<CenteredAffineTransform<float,3> >::RegisterTransform ();
     TransformFactory<CenteredEuler3DTransform<float> >::RegisterTransform ();
+    TransformFactory<CenteredRigid2DTransform < float > >::RegisterTransform();
     TransformFactory<CenteredSimilarity2DTransform<float> >::RegisterTransform ();
+    TransformFactory<Similarity2DTransform<float> >::RegisterTransform ();
     TransformFactory<Euler2DTransform<float> >::RegisterTransform ();
     TransformFactory<Euler3DTransform<float> >::RegisterTransform ();
     TransformFactory<FixedCenterOfRotationAffineTransform<float> >::RegisterTransform ();
