@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkVector.h,v $
   Language:  C++
-  Date:      $Date: 2007-02-05 13:35:53 $
-  Version:   $Revision: 1.80 $
+  Date:      $Date: 2008-05-12 21:11:21 $
+  Version:   $Revision: 1.82 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -269,14 +269,19 @@ ITKCommon_EXPORT Vector<int,3> CrossProduct( const Vector<int,3> &,
 # include "Templates/itkVector+-.h"
 #endif
 
+//
+// Numeric traits must be included after (optionally) including the explicit
+// instantiations control of this class, in case the implicit instantiation
+// needs to be disabled. 
+//
+// NumericTraits must be included before (optionally) including the .txx file,
+// in case the .txx requires to use NumericTraits.
+//
+#include "itkNumericTraitsVectorPixel.h"
+
 #if ITK_TEMPLATE_TXX
 # include "itkVector.txx"
 #endif
 
 
-#if ITK_TEMPLATE_EXPLICIT
-  #include "itkNumericTraitsVectorPixel.h"
-#endif
-
-
 #endif
