@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkVectorImageToImageAdaptor.h,v $
   Language:  C++
-  Date:      $Date: 2006-03-07 20:54:27 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date: 2008-08-04 15:56:22 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -124,7 +124,7 @@ public:
   itkNewMacro(Self);  
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( VectorImageToImagePixelAccessor, ImageAdaptor );
+  itkTypeMacro( VectorImageToImageAdaptor, ImageAdaptor );
 
   /** PixelContainer typedef support. Used to construct a container for
    * the pixel data. */
