@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkVectorInterpolateImageFunction.h,v $
   Language:  C++
-  Date:      $Date: 2006-02-06 22:01:58 $
-  Version:   $Revision: 1.19 $
+  Date:      $Date: 2008-05-14 09:26:05 $
+  Version:   $Revision: 1.23 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -53,22 +53,17 @@ struct GetDimension
  * \sa InterpolateImageFunction
  * \ingroup ImageFunctions ImageInterpolators
  */
-template <
-class TInputImage,
-class TCoordRep = float,
-class TPixelType = ITK_TYPENAME TInputImage::PixelType
->
-class ITK_EXPORT VectorInterpolateImageFunction : 
+template <class TInputImage, class TCoordRep = double>
+class ITK_EXPORT VectorInterpolateImageFunction :
   public ImageFunction<
-    TInputImage, 
-    FixedArray< ITK_TYPENAME NumericTraits<typename TPixelType::ValueType>::RealType, 
-      ::itk::GetDimension<TPixelType>::Dimension>,
-    TCoordRep > 
+    TInputImage,
+    ITK_TYPENAME NumericTraits<typename TInputImage::PixelType>::RealType,
+    TCoordRep >
 {
 public:
   /** Extract the vector dimension from the pixel template parameter. */
   itkStaticConstMacro(Dimension, unsigned int,
-                      TPixelType::Dimension);
+                      TInputImage::PixelType::Dimension);
   
   /** Dimension underlying input image. */
   itkStaticConstMacro(ImageDimension, unsigned int,
@@ -77,7 +72,8 @@ public:
   /** Standard class typedefs. */
   typedef VectorInterpolateImageFunction Self;
   typedef ImageFunction<TInputImage,
-    FixedArray<double, itkGetStaticConstMacro(Dimension)>, TCoordRep > Superclass;
+    ITK_TYPENAME NumericTraits<typename TInputImage::PixelType>::RealType,
+    TCoordRep > Superclass;
   typedef SmartPointer<Self> Pointer;
   typedef SmartPointer<const Self>  ConstPointer;
   
@@ -89,7 +85,6 @@ public:
   typedef typename InputImageType::PixelType  PixelType;
   typedef typename PixelType::ValueType       ValueType;
   typedef typename NumericTraits<ValueType>::RealType  RealType;
-    
 
   /** Point typedef support. */
   typedef typename Superclass::PointType PointType;
@@ -100,7 +95,7 @@ public:
   /** ContinuousIndex typedef support. */
   typedef typename Superclass::ContinuousIndexType ContinuousIndexType;
 
-  /** Output type is FixedArray<RealType,Dimension>. */
+  /** Output type is RealType of TInputImage::PixelType. */
   typedef typename Superclass::OutputType OutputType;
 
   /** CoordRep typedef support. */
