@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itk_hash_map.h,v $
   Language:  C++
-  Date:      $Date: 2007-11-01 19:25:09 $
-  Version:   $Revision: 1.16 $
+  Date:      $Date: 2008-05-26 00:26:09 $
+  Version:   $Revision: 1.20 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -61,7 +61,13 @@
 #if (defined(__GNUC__) && (((__GNUC__==3) && (__GNUC_MINOR__>=1) || (__GNUC__>3) ) || ( (__GNUC__==4) && defined(__INTEL_COMPILER) ) )) || (defined(__IBMCPP__) && __IBMCPP__ >= 600)
 // Use this hash_map for GNU_C versions >= 3.1, IBMCPP >=600, or Intel compilers with GCCv4
 
+// #if (defined(__GNUC__) && ((__GNUC__==4) && (__GNUC_MINOR__>=3) ) )
+// in gcc 4.3 the header <ext/hash_map> was deprecated and replaced with <unordered_map>.
+// note that this is still experimental in gcc 4.3
+// #include <tr1/unordered_map>
+// #else
 #include <ext/hash_map>
+// #endif
 
 namespace itk
 {
@@ -177,10 +183,9 @@ public:
   size_type max_size() const { return rep.max_size(); }
   bool empty() const { return rep.empty(); }
   void swap(self& hs) { rep.swap(hs.rep); }
-#ifndef __BORLANDC__
-  friend bool operator==VCL_NULL_TMPL_ARGS(const hash_map<Key,T,HashFcn,EqualKey,Alloc>&,
-                         const hash_map<Key,T,HashFcn,EqualKey,Alloc>&);
-#endif
+
+  friend bool operator==ITK_FRIEND_TEMPLATE_FUNCTION_ARGUMENT(self)(const self &, const self &);
+
   iterator begin() { return rep.begin(); }
   iterator end() { return rep.end(); }
   const_iterator begin() const { return rep.begin(); }
@@ -282,8 +287,8 @@ public:
   size_type max_size() const { return rep.max_size(); }
   bool empty() const { return rep.empty(); }
   void swap(self& hs) { rep.swap(hs.rep); }
-  friend bool operator==VCL_NULL_TMPL_ARGS(const hash_multimap<Key,T,HashFcn,EqualKey,Alloc>&,
-                         const hash_multimap<Key,T,HashFcn,EqualKey,Alloc>&);
+
+  friend bool operator==ITK_FRIEND_TEMPLATE_FUNCTION_ARGUMENT(self)(const self &, const self &);
 
   iterator begin() { return rep.begin(); }
   iterator end() { return rep.end(); }
@@ -320,15 +325,19 @@ public:
     { return rep.elems_in_bucket(n); }
 };
 
+/** This method MUST NOT be declared "inline" because it a specialization of its template is 
+    declared as friend of a class. The hash_map class, in this case */ 
 template <class Key, class T, class HashFcn, class EqualKey, class Alloc>
-inline bool operator==(const hash_map<Key, T, HashFcn, EqualKey, Alloc>& hm1,
+bool operator==(const hash_map<Key, T, HashFcn, EqualKey, Alloc>& hm1,
                        const hash_map<Key, T, HashFcn, EqualKey, Alloc>& hm2)
 {
   return hm1.rep == hm2.rep;
 }
 
+/** This method MUST NOT be declared "inline" because it a specialization of its template is 
+    declared as friend of a class. The hash_map class, in this case */ 
 template <class Key, class T, class HashFcn, class EqualKey, class Alloc>
-inline bool operator==(const hash_multimap<Key, T, HashFcn, EqualKey, Alloc>& hm1,
+bool operator==(const hash_multimap<Key, T, HashFcn, EqualKey, Alloc>& hm1,
                        const hash_multimap<Key, T, HashFcn, EqualKey, Alloc>& hm2)
 {
   return hm1.rep == hm2.rep;
