@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itk_hash_set.h,v $
   Language:  C++
-  Date:      $Date: 2006-10-16 01:31:24 $
-  Version:   $Revision: 1.11 $
+  Date:      $Date: 2008-05-23 20:45:13 $
+  Version:   $Revision: 1.13 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -146,8 +146,8 @@ public:
   size_type max_size() const { return rep.max_size(); }
   bool empty() const { return rep.empty(); }
   void swap(self& hs) { rep.swap(hs.rep); }
-  friend bool operator==VCL_NULL_TMPL_ARGS(const hash_set<Value,HashFcn,EqualKey,Alloc>&,
-                           const hash_set<Value,HashFcn,EqualKey,Alloc>&);
+
+  friend bool operator==ITK_FRIEND_TEMPLATE_FUNCTION_ARGUMENT(self)(const self &, const self &);
 
   iterator begin() const { return rep.begin(); }
   iterator end() const { return rep.end(); }
@@ -260,8 +260,8 @@ public:
   size_type max_size() const { return rep.max_size(); }
   bool empty() const { return rep.empty(); }
   void swap(self& hs) { rep.swap(hs.rep); }
-  friend bool operator==VCL_NULL_TMPL_ARGS(const hash_multiset<Value,HashFcn,EqualKey,Alloc>&,
-                         const hash_multiset<Value,HashFcn,EqualKey,Alloc>&);
+
+  friend bool operator==ITK_FRIEND_TEMPLATE_FUNCTION_ARGUMENT(self)(const self &, const self &);
 
   iterator begin() const { return rep.begin(); }
   iterator end() const { return rep.end(); }
@@ -294,15 +294,19 @@ public:
 };
 
 
+/** This method MUST NOT be declared "inline" because it a specialization of its template is 
+    declared as friend of a class. The hash_set class, in this case */ 
 template <class Value, class HashFcn, class EqualKey, class Alloc>
-inline bool operator==(const hash_set<Value, HashFcn, EqualKey, Alloc>& hs1,
+bool operator==(const hash_set<Value, HashFcn, EqualKey, Alloc>& hs1,
                        const hash_set<Value, HashFcn, EqualKey, Alloc>& hs2)
 {
   return hs1.rep == hs2.rep;
 }
 
+/** This method MUST NOT be declared "inline" because it a specialization of its template is 
+    declared as friend of a class. The hash_set class, in this case */ 
 template <class Value, class HashFcn, class EqualKey, class Alloc>
-inline bool operator==(const hash_multiset<Value, HashFcn, EqualKey, Alloc>& hs1,
+bool operator==(const hash_multiset<Value, HashFcn, EqualKey, Alloc>& hs1,
                        const hash_multiset<Value, HashFcn, EqualKey, Alloc>& hs2)
 {
   return hs1.rep == hs2.rep;
