@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itk_hashtable.h,v $
   Language:  C++
-  Date:      $Date: 2007-11-01 19:25:10 $
-  Version:   $Revision: 1.22 $
+  Date:      $Date: 2008-05-23 19:07:16 $
+  Version:   $Revision: 1.27 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -68,6 +68,13 @@
 #ifndef itk_emulation_hashtable_h
 #define itk_emulation_hashtable_h
 
+#if defined(_MSC_VER)
+// unreachable code
+#pragma warning ( disable : 4702 )
+// assignment operator could not be generated
+#pragma warning ( disable : 4512 )
+#endif
+
 #if (defined(__GNUC__) && (((__GNUC__==3) && (__GNUC_MINOR__>=1) || (__GNUC__>3) ) || ( (__GNUC__==4) && defined(__INTEL_COMPILER) ) )) || (defined(__IBMCPP__) && __IBMCPP__ >= 600)
 // Use this hashtable that is already define for GNU_C versions >= 3.1, IBMCPP >=600, or Intel compilers with GCCv4
 
@@ -443,9 +450,8 @@ public:
 
   const_iterator end() const { return const_iterator((node*)0, this); }
 
-  //  friend IUEi_STL_INLINE bool operator== VCL_NULL_TMPL_ARGS (const
-  //  self&,const self&);
-  friend bool operator== VCL_NULL_TMPL_ARGS (const self&,const self&);
+  friend bool operator==ITK_FRIEND_TEMPLATE_FUNCTION_ARGUMENT(self)(const self&,const self&);
+
 public:
 
   size_type bucket_count() const { return this->buckets.size(); }
@@ -697,8 +703,9 @@ distance_type(const hashtable_const_iterator<Value, Key, HashFcn, ExtractKey, Eq
 
 
 
+/** This method MUST NOT be declared "inline" because it a specialization of its template is 
+    declared as friend of a class. The hashtable class, in this case */ 
 template <class Value, class Key, class HashFcn, class ExtractKey, class EqualKey, class Alloc>
-IUEi_STL_INLINE 
 bool operator==(const hashtable<Value, Key, HashFcn, ExtractKey, EqualKey, Alloc>& ht1,
                 const hashtable<Value, Key, HashFcn, ExtractKey, EqualKey, Alloc>& ht2)
 {
