@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkDICOMImageIO2.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-01-25 00:00:05 $
-  Version:   $Revision: 1.29 $  
+  Date:      $Date: 2008-05-08 15:28:20 $
+  Version:   $Revision: 1.30 $  
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -15,7 +15,7 @@
 
 =========================================================================*/
 
-#ifdef WIN32
+#ifdef _MSC_VER
 #pragma warning(disable:4786)
 #endif
 
