@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkIOCommon.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-12-31 16:05:01 $
-  Version:   $Revision: 1.24 $
+  Date:      $Date: 2008-05-27 11:43:21 $
+  Version:   $Revision: 1.27 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -16,6 +16,7 @@
 =========================================================================*/
 #include "itkIOCommon.h"
 #include <sys/stat.h>
+#include <cstring>
 
 
 namespace itk
@@ -134,10 +135,19 @@ unsigned int IOCommon
     }
 }
 
-
+/**
+ * This method has been deprecated as of ITK 3.8.
+ * Please use the method:
+ * itksys::SystemTools::GetFilenameName(fileName) instead.
+ */
+#if !defined(ITK_LEGACY_REMOVE)
 char* IOCommon
 ::ExtractFileName (const char* fileName)
 {
+  itkGenericLegacyReplaceBodyMacro(itk::IOCommon::ExtractFileName, 
+                                   3.6, 
+                                   itksys::SystemTools::GetFilenameName);
+
   const char* dot;
   const char* slash;
   char* fName = NULL;
@@ -169,10 +179,22 @@ char* IOCommon
 
   return fName;
 }
+#endif
 
+/**
+ * This method has been deprecated as of ITK 3.8.
+ * Please use the method:
+ * itksys::SystemTools::GetFilenameExtension(fileName) or
+ * itksys::SystemTools::GetFilenameLastExtension(fileName) instead.
+ */
+#if !defined(ITK_LEGACY_REMOVE)
 char* IOCommon
 ::ExtractFileExtension (const char* fileName)
 {
+  itkGenericLegacyReplaceBodyMacro(itk::IOCommon::ExtractFileExtension, 
+                                   3.6, 
+                                   itksys::SystemTools::GetFilenameExtension);
+
   const char* dot;
   char* fExtension = NULL;
 
@@ -187,10 +209,21 @@ char* IOCommon
 
   return fExtension;
 }
+#endif
 
+/**
+ * This method has been deprecated as of ITK 3.8.
+ * Please use the method:
+ * itksys::SystemTools::GetFilenamePath(fileName) instead.
+ */
+#if !defined(ITK_LEGACY_REMOVE)
 char* IOCommon
 ::ExtractFilePath (const char* fileName)
 {
+  itkGenericLegacyReplaceBodyMacro(itk::IOCommon::ExtractFilePath, 
+                                   3.6, 
+                                   itksys::SystemTools::GetFilenamePath);
+
   const char* slash;
   char* fPath = NULL;
 
@@ -216,6 +249,7 @@ char* IOCommon
 
   return fPath;
 }
+#endif
 
 
 } // namespace itk
