@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkImageIOBase.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-02-06 21:23:04 $
-  Version:   $Revision: 1.75 $
+  Date:      $Date: 2008-09-15 16:49:32 $
+  Version:   $Revision: 1.80 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -62,6 +62,28 @@ ImageIOBase::~ImageIOBase()
 {
 }
 
+const ImageIOBase::ArrayOfExtensionsType & 
+ImageIOBase::GetSupportedWriteExtensions() const
+{
+  return this->m_SupportedWriteExtensions;
+}
+ 
+const ImageIOBase::ArrayOfExtensionsType & 
+ImageIOBase::GetSupportedReadExtensions() const
+{
+  return this->m_SupportedReadExtensions;
+}
+
+void ImageIOBase::AddSupportedReadExtension( const char * extension )
+{
+  this->m_SupportedReadExtensions.push_back( extension );
+}
+
+void ImageIOBase::AddSupportedWriteExtension( const char * extension )
+{
+  this->m_SupportedWriteExtensions.push_back( extension );
+}
+
 void ImageIOBase::Resize(const unsigned int numDimensions,
                          const unsigned int* dimensions)
 {
@@ -78,35 +100,75 @@ void ImageIOBase::Resize(const unsigned int numDimensions,
 
 void ImageIOBase::SetDimensions(unsigned int i, unsigned int dim)
 {
-  if ( i >= m_Dimensions.size() ) {return;}
+  if ( i >= m_Dimensions.size() ) 
+    {
+    itkWarningMacro("Index: " << i <<
+                      " is out of bounds, expected maximum is " <<
+                      m_Dimensions.size());
+    itkExceptionMacro("Index: " << i <<
+                      " is out of bounds, expected maximum is " <<
+                      m_Dimensions.size());
+    }
   this->Modified();
   m_Dimensions[i] = dim;
 }
 
 void ImageIOBase::SetOrigin(unsigned int i, double origin)
 {
-  if ( i >= m_Origin.size() ) {return;}
+  if ( i >= m_Origin.size() ) 
+    {
+    itkWarningMacro("Index: " << i <<
+                      " is out of bounds, expected maximum is " <<
+                      m_Origin.size());
+    itkExceptionMacro("Index: " << i <<
+                      " is out of bounds, expected maximum is " <<
+                      m_Origin.size());
+    }
   this->Modified();
   m_Origin[i] = origin;
 }
 
 void ImageIOBase::SetSpacing(unsigned int i, double spacing)
 {
-  if (i >= m_Spacing.size() ) {return;}
+  if (i >= m_Spacing.size() ) 
+    {
+    itkWarningMacro("Index: " << i <<
+                      " is out of bounds, expected maximum is " <<
+                      m_Spacing.size());
+    itkExceptionMacro("Index: " << i <<
+                      " is out of bounds, expected maximum is " <<
+                      m_Spacing.size());
+    }
   this->Modified();
   m_Spacing[i] = spacing;
 }
 
 void ImageIOBase::SetDirection(unsigned int i, std::vector<double> &direction)
 {
-  if (i >= m_Direction.size() ) {return;}
+  if (i >= m_Direction.size() ) 
+    {
+    itkWarningMacro("Index: " << i <<
+                      " is out of bounds, expected maximum is " <<
+                      m_Direction.size());
+    itkExceptionMacro("Index: " << i <<
+                      " is out of bounds, expected maximum is " <<
+                      m_Direction.size());
+    }
   this->Modified();
   m_Direction[i] = direction;
 }
 
 void ImageIOBase::SetDirection(unsigned int i, vnl_vector<double> &direction)
 {
-  if (i >= m_Direction.size() ) {return;}
+  if (i >= m_Direction.size() ) 
+    {
+    itkWarningMacro("Index: " << i <<
+                      " is out of bounds, expected maximum is " <<
+                      m_Direction.size());
+    itkExceptionMacro("Index: " << i <<
+                      " is out of bounds, expected maximum is " <<
+                      m_Direction.size());
+    }
   this->Modified();
   std::vector<double> v;
   v.resize(m_Direction.size());
@@ -506,6 +568,8 @@ void ImageIOBase::SetNumberOfDimensions(unsigned int dim)
           }
         }
       this->SetDirection(i, axis);
+      this->SetOrigin(i, 0.0);
+      this->SetSpacing(i, 1.0);
       }
     this->Modified();
     }
@@ -516,11 +580,11 @@ ImageIOBase
 ::ReadBufferAsBinary(std::istream& is, void *buffer, ImageIOBase::SizeType num)
 {
 
-  const SizeType numberOfBytesToBeRead = num;
+  const std::streamsize numberOfBytesToBeRead = static_cast< std::streamsize>( num );
 
   is.read( static_cast<char *>( buffer ), numberOfBytesToBeRead );
 
-  const SizeType numberOfBytesRead = is.gcount();
+  const std::streamsize numberOfBytesRead = is.gcount();
 
 #ifdef __APPLE_CC__
   // fail() is broken in the Mac. It returns true when reaches eof().
