@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMetaImageIO.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-02-19 17:38:49 $
-  Version:   $Revision: 1.85 $
+  Date:      $Date: 2008-06-25 11:30:38 $
+  Version:   $Revision: 1.87 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -41,6 +41,13 @@ MetaImageIO::MetaImageIO()
     {
     m_ByteOrder = LittleEndian;
     }
+
+  this->AddSupportedWriteExtension(".mha");
+  this->AddSupportedWriteExtension(".mhd");
+
+  this->AddSupportedReadExtension(".mha");
+  this->AddSupportedReadExtension(".mhd");
+
 } 
 
 MetaImageIO::~MetaImageIO()
@@ -1004,7 +1011,7 @@ MetaImageIO
   for(i=0; i<nDims; i++)
     {
     dSize[i] = this->GetDimensions(i);
-    eSpacing[i] = this->GetSpacing(i);
+    eSpacing[i] = static_cast<float>(this->GetSpacing(i));
     eOrigin[i] = this->GetOrigin(i);
     } 
   ImageIORegion::IndexType indx = this->GetIORegion().GetIndex();
