@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkOnePlusOneEvolutionaryOptimizer.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-03-22 14:29:13 $
-  Version:   $Revision: 1.34 $
+  Date:      $Date: 2008-08-06 16:14:46 $
+  Version:   $Revision: 1.37 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -26,6 +26,9 @@ namespace itk
 OnePlusOneEvolutionaryOptimizer
 ::OnePlusOneEvolutionaryOptimizer()
 {
+  m_CatchGetValueException = false;
+  m_MetricWorstPossibleValue = 0;
+
   m_Maximize = false;
   m_Epsilon = (double) 1.5e-4; 
   m_RandomGenerator = 0;
@@ -109,8 +112,26 @@ OnePlusOneEvolutionaryOptimizer
     parentPosition[i] = parent[i];
     }
 
+  double pvalue = m_MetricWorstPossibleValue;
+  try
+    {
+    pvalue = m_CostFunction->GetValue(parentPosition);
+    }
+  catch( ... )
+    {
+    if(m_CatchGetValueException)
+      {
+      pvalue = m_MetricWorstPossibleValue;
+      }
+    else
+      {
+      throw;
+      }
+    }
+
   itkDebugMacro(<< ": initial position: " << parentPosition); 
-  double pvalue = m_CostFunction->GetValue(parentPosition);
+  itkDebugMacro(<< ": initial fitness: " << pvalue); 
+
   this->SetCurrentPosition(parentPosition);
   const Optimizer::ScalesType& scales = this->GetScales();
 
@@ -157,16 +178,41 @@ OnePlusOneEvolutionaryOptimizer
       childPosition[i] = child[i];
       }
 
-    double cvalue = m_CostFunction->GetValue(childPosition);
+    double cvalue = m_MetricWorstPossibleValue;
+    try
+      {
+      cvalue = m_CostFunction->GetValue(childPosition);
+      }
+    catch( ... )
+      {
+      if(m_CatchGetValueException)
+        {
+        cvalue = m_MetricWorstPossibleValue;
+        }
+      else
+        {
+        throw;
+        }
+      }
 
-    itkDebugMacro(<< iter << ": parent: " << pvalue 
-                  << " child: "<< cvalue );
+    itkDebugMacro(<< "iter: " << iter << ": parent position: " 
+                  << parentPosition);
+    itkDebugMacro(<< "iter: " << iter << ": parent fitness: " 
+                  << pvalue); 
+    itkDebugMacro(<< "iter: " << iter << ": random vector: " << f_norm); 
+    itkDebugMacro(<< "iter: " << iter << ": A: " << std::endl << A); 
+    itkDebugMacro(<< "iter: " << iter << ": delta: " << delta); 
+    itkDebugMacro(<< "iter: " << iter << ": child position: " 
+                  << childPosition); 
+    itkDebugMacro(<< "iter: " << iter << ": child fitness: " 
+                  << cvalue); 
 
     double adjust = m_ShrinkFactor;
     if( m_Maximize )
       {
       if (cvalue > pvalue) 
         {
+        itkDebugMacro(<< "iter: " << iter << ": increasing search radius");
         pvalue = cvalue;
         parent.swap(child);
         adjust = m_GrowthFactor; 
@@ -176,11 +222,16 @@ OnePlusOneEvolutionaryOptimizer
           }
         this->SetCurrentPosition(parentPosition);
         } 
+      else
+        {
+        itkDebugMacro(<< "iter: " << iter << ": decreasing search radius");
+        }
       }
     else
       {
       if (cvalue < pvalue) 
         {
+        itkDebugMacro(<< "iter: " << iter << ": increasing search radius");
         pvalue = cvalue;
         parent.swap(child);
         adjust = m_GrowthFactor; 
@@ -189,6 +240,10 @@ OnePlusOneEvolutionaryOptimizer
           parentPosition[i] = parent[i];
           }
         this->SetCurrentPosition(parentPosition);
+        }
+      else
+        {
+        itkDebugMacro(<< "iter: " << iter << ": decreasing search radius");
         } 
       }
 
@@ -262,7 +317,10 @@ OnePlusOneEvolutionaryOptimizer
   os << indent << "Current Iteration " << m_CurrentIteration << std::endl;
   os << indent << "Frobenius Norm    " << m_FrobeniusNorm    << std::endl;
   os << indent << "Maximize On/Off   " << m_Maximize         << std::endl;
-
+  os << indent << "CatchGetValueException   " << m_CatchGetValueException 
+               << std::endl;
+  os << indent << "MetricWorstPossibleValue " << m_MetricWorstPossibleValue 
+               << std::endl;
 }
 
 } // end of namespace itk
