@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkPowellOptimizer.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-10-19 07:55:22 $
-  Version:   $Revision: 1.15 $
+  Date:      $Date: 2008-05-22 08:33:35 $
+  Version:   $Revision: 1.19 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -27,6 +27,9 @@ namespace itk
 PowellOptimizer
 ::PowellOptimizer()
 {
+  m_CatchGetValueException = false;
+  m_MetricWorstPossibleValue = 0;
+
   m_Maximize = false;
 
   m_StepLength = 1.0;
@@ -55,11 +58,10 @@ PowellOptimizer
 ::SetLine(const PowellOptimizer::ParametersType & origin,
           const vnl_vector<double> & direction)
 {
-  m_LineOrigin = origin;
-  m_LineDirection = direction;
   for(unsigned int i=0; i<m_SpaceDimension; i++)
     {
-    m_LineDirection[i] = m_LineDirection[i] / this->GetScales()[i];
+    m_LineOrigin[i] = origin[i];
+    m_LineDirection[i] = direction[i] / this->GetScales()[i];
     }
 }
 
@@ -67,31 +69,51 @@ double
 PowellOptimizer
 ::GetLineValue(double x) const
 {
-  PowellOptimizer::ParametersType xCoord( m_SpaceDimension );
+  PowellOptimizer::ParametersType tempCoord( m_SpaceDimension );
+  return this->GetLineValue(x, tempCoord);
+}
+
+double
+PowellOptimizer
+::GetLineValue(double x, ParametersType & tempCoord) const
+{
   for(unsigned int i=0; i<m_SpaceDimension; i++)
     {
-    xCoord[i] = this->m_LineOrigin[i] + x * this->m_LineDirection[i];
+    tempCoord[i] = this->m_LineOrigin[i] + x * this->m_LineDirection[i];
+    }
+  itkDebugMacro( << "x = " << x );
+  double val;
+  try
+    {
+    val = (this->m_CostFunction->GetValue(tempCoord));
+    }
+  catch( ... )
+    {
+    if(m_CatchGetValueException)
+      {
+      val = m_MetricWorstPossibleValue;
+      }
+    else
+      {
+      throw;
+      }
     }
   if(m_Maximize)
     {
-    return -(this->m_CostFunction->GetValue(xCoord));
-    }
-  else
-    {
-    return this->m_CostFunction->GetValue(xCoord);
+    val = -val;
     }
+  itkDebugMacro( << "val = " << val );
+  return val;
 }
 
 void
 PowellOptimizer
 ::SetCurrentLinePoint(double x, double fx)
 {
-  PowellOptimizer::ParametersType xCoord( m_SpaceDimension );
   for(unsigned int i=0; i<m_SpaceDimension; i++)
     {
-    xCoord[i] = this->m_LineOrigin[i] + x * this->m_LineDirection[i];
+    this->m_CurrentPosition[i] = this->m_LineOrigin[i] + x * this->m_LineDirection[i];
     }
-  this->SetCurrentPosition(xCoord);
   if(m_Maximize)
     {
     this->SetCurrentCost(-fx);
@@ -100,6 +122,7 @@ PowellOptimizer
     {
     this->SetCurrentCost(fx);
     }
+  this->Modified();
 }
 
 void
@@ -143,6 +166,16 @@ void
 PowellOptimizer
 ::LineBracket(double * x1, double * x2, double * x3,
               double * f1, double * f2, double * f3)
+{
+  PowellOptimizer::ParametersType tempCoord( m_SpaceDimension );
+  this->LineBracket( x1, x2, x3, f1, f2, f3, tempCoord);
+}
+
+void
+PowellOptimizer
+::LineBracket(double * x1, double * x2, double * x3,
+              double * f1, double * f2, double * f3,
+              ParametersType & tempCoord)
 {
   //
   // Compute the golden ratio as a constant to be
@@ -153,124 +186,35 @@ PowellOptimizer
   //
   // Get the value of the function for point x2
   //
-  *f2 = this->GetLineValue( *x2 );
+  *f2 = this->GetLineValue( *x2, tempCoord );
 
   //
   // Compute extrapolated point using the golden ratio
   //
-  if( *f2 < *f1 )
+  if( *f2 >= *f1 )
     {
-    // compute x3 on the side of x2
+    this->Swap(x1, x2);
+    this->Swap(f1, f2);
+    }
+  
+  // compute x3 on the side of x2
+  *x3 = *x1 + goldenRatio * ( *x2 - *x1 );
+  *f3 = this->GetLineValue( *x3, tempCoord );
+  
+  // If the new point is a minimum
+  // then continue extrapolating in
+  // that direction until we find a
+  // value of f3 that makes f2 to be
+  // a minimum.
+  while( *f3 < *f2 )
+    {
+    *x2 = *x3;
+    *f2 = *f3;
     *x3 = *x1 + goldenRatio * ( *x2 - *x1 );
-    *f3 = this->GetLineValue( *x3 );
-
-    // If the new point is a minimum
-    // then continue extrapolating in
-    // that direction until we find a
-    // value of f3 that makes f2 to be
-    // a minimum.
-    while( *f3 < *f2 )
-      {
-      *x2 = *x3;
-      *f2 = *f3;
-      *x3 = *x1 + goldenRatio * ( *x2 - *x1 );
-      *f3 = this->GetLineValue( *x3 );
-      }
-    }
-  else
-    {
-    // compute x3 on the side of x1
-    *x3 = *x2 + goldenRatio * ( *x1 - *x2 );
-    *f3 = this->GetLineValue( *x3 );
-
-    // If the new point is a minimum
-    // then continue extrapolating in
-    // that direction until we find a
-    // value of f3 that makes f2 to be
-    // a minimum.
-    while( *f3 < *f1 )
-      {
-      *x1 = *x3;
-      *f1 = *f3;
-      *x3 = *x2 + goldenRatio * ( *x1 - *x2 );
-      *f3 = this->GetLineValue( *x3 );
-      }
+    *f3 = this->GetLineValue( *x3, tempCoord );
     }
 
-  const double POWELL_TINY = 1.0e-20;
-
-  double intervalWidth;
-  double floatingPointPrecision;
-
-  double x4memory;
-  double f4memory;
-
-  double * x4 = & x4memory;
-  double * f4 = & f4memory;
-
-  //
-  // Now that the function is bracketed as
-  //
-  //      f1 >  f2  < f3
-  //
-  // then start searching for the minimum
-  // inside of the bracket by using a golden
-  // section search
-  //
-  do
-    {
-    //
-    // Compute the next point using the golden ratio.
-    // At this point this can be done by simply using
-    // the additive property of the golden ratio, there
-    // is no need for using it as a factor.
-    //
-    *x4 = *x1 - *x2 + *x3;
-    *f4 = this->GetLineValue( *x4 );
-
-    //
-    // If the new value f4 at x4 is larger than f2
-    // then the minimum should be between x1 and x4,
-    //
-    if( *f2 < *f4 )
-      {
-      // Therefore the new triplet should be
-      // composed of x1,x2,x4. We make x3,f3
-      // take the values of x4,f4 and we are
-      // back to having a bracket x1,x2,x3.
-      //
-      *x3 = *x4;
-      *f3 = *f4;
-      }
-    else
-      {
-      //
-      // Otherwise the minimum should be between x2 and x3
-      // Therefore the new triplet should be
-      // composed of x2,x4,x3. We make x1,f1
-      // take the values of x2,f2, and we make
-      // x2,f2 take the values of x4,f4. At that
-      // point we are back to having a bracket x1,x2,x3.
-      //
-      *x1 = *x2;
-      *f1 = *f2;
-      *x2 = *x4;
-      *f2 = *f4;
-      }
-
-    //
-    // Check if the interval is so small that the
-    // floating point precision will not change
-    // in a further search
-    //
-    intervalWidth = vcl_abs( *x3 - *x1 );
-
-    floatingPointPrecision =
-     POWELL_TINY * vcl_abs( *x2 ) + vcl_abs( *x4 );
-
-    }
-  while( intervalWidth > floatingPointPrecision );
-
+  itkDebugMacro( << "Initial: " << *x1 << ", " << *x2 << ", " << *x3 );
   //
   // Report the central point as the minimum
   //
@@ -280,8 +224,19 @@ PowellOptimizer
 void
 PowellOptimizer
 ::BracketedLineOptimize(double ax, double bx, double cx,
-                        double itkNotUsed(fa), double functionValueOfb, double itkNotUsed(fc),
+                        double fa, double functionValueOfb, double fc,
                         double * extX, double * extVal)
+{
+  PowellOptimizer::ParametersType tempCoord( m_SpaceDimension );
+  this->BracketedLineOptimize( ax, bx, cx, fa, functionValueOfb, fc, extX, extVal, tempCoord);
+}
+
+void
+PowellOptimizer
+::BracketedLineOptimize(double ax, double bx, double cx,
+                        double itkNotUsed(fa), double functionValueOfb, double itkNotUsed(fc),
+                        double * extX, double * extVal,
+                        ParametersType & tempCoord)
 {
   double x;
   double v = 0.0;
@@ -327,6 +282,9 @@ PowellOptimizer
       *extX = x;
       *extVal = functionValueOfX;
       this->SetCurrentLinePoint(x, functionValueOfX);
+      itkDebugMacro( << "x = " << *extX );
+      itkDebugMacro( << "val = " << *extVal );
+      itkDebugMacro( << "return 1" );
       return;        /* Acceptable approx. is found  */
       }
 
@@ -389,7 +347,7 @@ PowellOptimizer
 
     double functionValueOft;
 
-    functionValueOft = this->GetLineValue(t);
+    functionValueOft = this->GetLineValue(t, tempCoord);
 
     if( functionValueOft <= functionValueOfX )
     {
@@ -439,6 +397,9 @@ PowellOptimizer
 
   *extX = x;
   *extVal = functionValueOfX;
+  itkDebugMacro( << "x = " << *extX );
+  itkDebugMacro( << "val = " << *extVal );
+  itkDebugMacro( << "return 2" );
 
   this->SetCurrentLinePoint(x, functionValueOfX);
 
@@ -459,6 +420,7 @@ PowellOptimizer
   m_SpaceDimension = m_CostFunction->GetNumberOfParameters();
   m_LineOrigin.set_size(m_SpaceDimension);
   m_LineDirection.set_size(m_SpaceDimension);
+  this->m_CurrentPosition.set_size(m_SpaceDimension);
 
   vnl_matrix<double> xi(m_SpaceDimension, m_SpaceDimension);
   vnl_vector<double> xit(m_SpaceDimension);
@@ -466,6 +428,8 @@ PowellOptimizer
   xit.fill(0);
   xit[0] = 1;
 
+  PowellOptimizer::ParametersType tempCoord(m_SpaceDimension);
+
   PowellOptimizer::ParametersType p(m_SpaceDimension);
   PowellOptimizer::ParametersType pt(m_SpaceDimension);
   PowellOptimizer::ParametersType ptt(m_SpaceDimension);
@@ -479,7 +443,7 @@ PowellOptimizer
 
   xx = 0;
   this->SetLine(p, xit);
-  fx = this->GetLineValue(0);
+  fx = this->GetLineValue(0, tempCoord);
 
   for (m_CurrentIteration = 0;
        m_CurrentIteration <= m_MaximumIteration;
@@ -502,8 +466,8 @@ PowellOptimizer
       ax = 0.0;
       fa = fx;
       xx = m_StepLength;
-      this->LineBracket( &ax, &xx, &bx, &fa, &fx, &fb);
-      this->BracketedLineOptimize(ax, xx, bx, fa, fx, fb, &xx, &fx);
+      this->LineBracket( &ax, &xx, &bx, &fa, &fx, &fb, tempCoord);
+      this->BracketedLineOptimize(ax, xx, bx, fa, fx, fb, &xx, &fx, tempCoord);
       this->SetCurrentLinePoint(xx, fx);
       p = this->GetCurrentPosition();
 
@@ -529,7 +493,7 @@ PowellOptimizer
       }
 
     this->SetLine(ptt, xit);
-    fptt = this->GetLineValue(0);
+    fptt = this->GetLineValue(0, tempCoord);
     if (fptt < fp)
       {
       double t = 2.0 * (fp - 2.0*fx + fptt)
@@ -542,8 +506,8 @@ PowellOptimizer
         ax = 0.0;
         fa = fx;
         xx = 1;
-        this->LineBracket( &ax, &xx, &bx, &fa, &fx, &fb);
-        this->BracketedLineOptimize(ax, xx, bx, fa, fx, fb, &xx, &fx);
+        this->LineBracket( &ax, &xx, &bx, &fa, &fx, &fb, tempCoord);
+        this->BracketedLineOptimize(ax, xx, bx, fa, fx, fb, &xx, &fx, tempCoord);
         this->SetCurrentLinePoint(xx, fx);
         p = this->GetCurrentPosition();
 
@@ -571,6 +535,8 @@ PowellOptimizer
 {
   Superclass::PrintSelf(os,indent);
 
+  os << indent << "Metric Worst Possible Value " << m_MetricWorstPossibleValue << std::endl;
+  os << indent << "Catch GetValue Exception " << m_CatchGetValueException   << std::endl;
   os << indent << "Space Dimension   " << m_SpaceDimension   << std::endl;
   os << indent << "Maximum Iteration " << m_MaximumIteration << std::endl;
   os << indent << "Current Iteration " << m_CurrentIteration << std::endl;
