@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkArrowSpatialObject.h,v $
   Language:  C++
-  Date:      $Date: 2006-06-06 15:42:16 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2008-04-19 22:31:05 $
+  Version:   $Revision: 1.6 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -111,7 +111,12 @@ public:
 
   /** Set the length of the arrow */
   void SetLength(double length);
-  void SetLenght(double length){this->SetLength(length); return;}
+  void SetLenght(double length)
+  {
+  itkWarningMacro("Please change your code to use SetLength rather than SetLenght. The latter method name was mispelled and the ITK developers failed to correct it before it was released. The mispelled method name is retained in order to maintain backward compatibility.");
+  this->SetLength(length);
+  return;
+  }
 
   /** Get the length of the arrow */
   itkGetMacro(Length,double);
