@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkSpatialObject.h,v $
   Language:  C++
-  Date:      $Date: 2007-01-28 19:24:56 $
-  Version:   $Revision: 1.64 $
+  Date:      $Date: 2008-06-29 01:56:15 $
+  Version:   $Revision: 1.65 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -554,6 +554,14 @@ protected:
   itkGetConstObjectMacro(Bounds,BoundingBoxType);
   itkGetConstObjectMacro(InternalInverseTransform,TransformType);
 
+  /** This convenience method take the IndexToWorldTransform, and 
+   * if it can compute its inverse, then stores the result in the 
+   * InternalInverse member variable, that can be later accessed 
+   * with the method GetInternalInverseTransform(). This method is
+   * not exposed to users, it is only intended to be called internally
+   * by derived classes. */
+  bool SetInternalInverseTransformToWorldToIndexTransform() const;
+
 private:
 
   SpatialObject(const Self&); //purposely not implemented
