@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkSpatialObjectTreeContainer.h,v $
   Language:  C++
-  Date:      $Date: 2007-07-16 23:15:51 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date: 2008-06-22 19:20:58 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -68,7 +68,7 @@ public:
   itkTypeMacro(SpatialObjectTreeContainer, TreeContainer);
 
   /** Set the root */
-  bool SetRoot(SpatialObjectPointer element);
+  bool SetRoot(const SpatialObjectPointer element);
   bool SetRoot(typename Superclass::TreeNodeType* node)
     {return Superclass::SetRoot(node);}
 
