@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: BSplineWarping1.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-04-11 16:01:02 $
-  Version:   $Revision: 1.20 $
+  Date:      $Date: 2008-04-21 17:40:10 $
+  Version:   $Revision: 1.22 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -226,18 +226,21 @@ int main( int argc, char * argv[] )
 
   typedef TransformType::SpacingType SpacingType;
   SpacingType spacing;
-  spacing[0] = fixedSpacing[0] * (fixedSize[0] - 1) / numberOfGridCells;
-  spacing[1] = fixedSpacing[1] * (fixedSize[1] - 1) / numberOfGridCells;
 
   typedef TransformType::OriginType OriginType;
   OriginType origin;
-  origin[0] = fixedOrigin[0] - spacing[0];
-  origin[1] = fixedOrigin[1] - spacing[1];
+
+  for( unsigned int i=0; i< SpaceDimension; i++ )
+    {
+    spacing[i] = fixedSpacing[i] * (fixedSize[i] - 1) / numberOfGridCells;
+    }
+  
+  origin  = fixedOrigin - fixedDirection * spacing;
   
   bsplineTransform->SetGridSpacing( spacing );
   bsplineTransform->SetGridOrigin( origin );
   bsplineTransform->SetGridRegion( bsplineRegion );
-  bsplineTransform->SetGridDirection( fixedImage->GetDirection() );
+  bsplineTransform->SetGridDirection( fixedDirection );
   
 
   typedef TransformType::ParametersType     ParametersType;
@@ -343,6 +346,7 @@ int main( int argc, char * argv[] )
   field->SetRegions( fixedRegion );
   field->SetOrigin( fixedOrigin );
   field->SetSpacing( fixedSpacing );
+  field->SetDirection( fixedDirection );
   field->Allocate();
 
   typedef itk::ImageRegionIterator< DeformationFieldType > FieldIterator;
@@ -361,8 +365,7 @@ int main( int argc, char * argv[] )
     index = fi.GetIndex();
     field->TransformIndexToPhysicalPoint( index, fixedPoint );
     movingPoint = bsplineTransform->TransformPoint( fixedPoint );
-    displacement[0] = movingPoint[0] - fixedPoint[0];
-    displacement[1] = movingPoint[1] - fixedPoint[1];
+    displacement = movingPoint - fixedPoint;
     fi.Set( displacement );
     ++fi;
     }
