@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: DeformableRegistration14.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-04-11 16:01:02 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date: 2008-04-21 16:57:13 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -279,13 +279,17 @@ int main( int argc, char *argv[] )
     {
     spacing[r] *= static_cast<double>(fixedImageSize[r] - 1)  / 
                   static_cast<double>(gridSizeOnImage[r] - 1);
-    origin[r]  -=  spacing[r]; 
     }
 
+  FixedImageType::DirectionType gridDirection = fixedImage->GetDirection();
+  SpacingType gridOriginOffset = gridDirection * spacing;
+
+  OriginType gridOrigin = origin - gridOriginOffset; 
+
   transform->SetGridSpacing( spacing );
-  transform->SetGridOrigin( origin );
+  transform->SetGridOrigin( gridOrigin );
   transform->SetGridRegion( bsplineRegion );
-  transform->SetGridDirection( fixedImage->GetDirection() );
+  transform->SetGridDirection( gridDirection );
   
 
   typedef TransformType::ParametersType     ParametersType;
@@ -514,6 +518,7 @@ int main( int argc, char *argv[] )
     field->SetRegions( fixedRegion );
     field->SetOrigin( fixedImage->GetOrigin() );
     field->SetSpacing( fixedImage->GetSpacing() );
+    field->SetDirection( fixedImage->GetDirection() );
     field->Allocate();
 
     typedef itk::ImageRegionIterator< DeformationFieldType > FieldIterator;
