@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkAlgorithmsTests4.cxx,v $
   Language:  C++
-  Date:      $Date: 2006-08-30 13:39:59 $
-  Version:   $Revision: 1.12 $
+  Date:      $Date: 2008-08-11 17:58:51 $
+  Version:   $Revision: 1.14 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -38,18 +38,22 @@ void RegisterTests()
   REGISTER_TEST(itkVnlFFTTest);
 #if defined(USE_FFTWF)
   REGISTER_TEST(itkFFTWF_FFTTest);
+  REGISTER_TEST(itkVnlFFTWF_FFTTest);
 #endif
 #if defined(USE_FFTWD)
   REGISTER_TEST(itkFFTWD_FFTTest);
+  REGISTER_TEST(itkVnlFFTWD_FFTTest);
 #endif
 #if defined(USE_FFTWD)
   REGISTER_TEST(itkCurvatureRegistrationFilterTest);
 #endif
 #if defined(USE_SCSL)
   REGISTER_TEST(itkSCSLFFTTest);
+  REGISTER_TEST(itkVnlSCSL_FFTTest);
 #endif
   REGISTER_TEST(itkMeanReciprocalSquareDifferencePointSetToImageMetricTest );
   REGISTER_TEST(itkMeanReciprocalSquareDifferencePointSetToImageMetricTest );
   REGISTER_TEST(itkThresholdMaximumConnectedComponentsImageFilterTest );
+  REGISTER_TEST(itkScalarImageKmeansImageFilter3DTest );
 }
 
