@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkCurvatureFlowTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-20 12:47:11 $
-  Version:   $Revision: 1.36 $
+  Date:      $Date: 2008-06-13 13:55:39 $
+  Version:   $Revision: 1.37 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -215,10 +215,20 @@ int itkCurvatureFlowTest(int argc, char* argv[] )
     streamer->GetOutput()->GetBufferedRegion() );
 
   bool testPass = true;
+  unsigned int failedPixels = 0;
   while( !it1.IsAtEnd() )
     {
     if( it1.Get() != it2.Get() )
-      { testPass = false; }
+      {
+      if (failedPixels == 0)
+        {
+        std::cout << "it1.Get() != it2.Get(): "
+                  << it1.Get() << " != " << it2.Get()
+                  << std::endl;
+        }
+      failedPixels++;
+      testPass = false;
+      }
     ++it1;
     ++it2;
     }
@@ -226,6 +236,7 @@ int itkCurvatureFlowTest(int argc, char* argv[] )
   if( !testPass )
     {
     std::cout << "Test failed." << std::endl;
+    std::cout << "Number of failed pixels: " << failedPixels << std::endl;
     return EXIT_FAILURE;
     }
 
