@@ -39,6 +39,9 @@ REGISTER_TEST(itkOctreeTest );
 REGISTER_TEST(itkOrthogonallyCorrected2DParametricPathTest );
 REGISTER_TEST(itkOrientedImage3DTest );
 REGISTER_TEST(itkOrientedImage2DTest );
+REGISTER_TEST(itkOrientedImageProfileTest1 );
+REGISTER_TEST(itkOrientedImageProfileTest2 );
+REGISTER_TEST(itkOrientedImageProfileTest3 );
 REGISTER_TEST(itkPathFunctionsTest );
 REGISTER_TEST(itkPathIteratorTest );
 REGISTER_TEST(itkPCAShapeSignedDistanceFunctionTest );
@@ -79,11 +82,13 @@ REGISTER_TEST(itkStdStreamLogOutputTest );
 REGISTER_TEST(itkThreadDefsTest );
 REGISTER_TEST(itkThreadLoggerTest );
 REGISTER_TEST(itkTimeProbesTest );
+REGISTER_TEST(itkTimeStampTest );
 REGISTER_TEST(itkTransformTest );
 REGISTER_TEST(itkTransformsSetParametersTest );
 REGISTER_TEST(itkTranslationTransformTest );
 REGISTER_TEST(itkTreeContainerTest );
 REGISTER_TEST(itkTreeContainerTest2 );
+REGISTER_TEST(itkTriangleCellTest );
 REGISTER_TEST(itkVarianceImageFunctionTest );
 REGISTER_TEST(itkVectorGeometryTest );
 REGISTER_TEST(itkVectorImageTest );
