@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkSystemInformationTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-02-16 21:00:51 $
-  Version:   $Revision: 1.16 $
+  Date:      $Date: 2008-05-26 02:39:38 $
+  Version:   $Revision: 1.17 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -21,6 +21,8 @@
 #include <iostream>
 #include <fstream>
 #include <string>
+#include <cstdlib>
+#include <cstring>
 #include <Code/Common/itkSystemInformationTest.h>
 #include <sys/stat.h>
 #include <time.h>
@@ -191,8 +193,8 @@ int main(int,char *[])
   Program:   Visualization Toolkit
   Module:    $RCSfile: itkSystemInformationTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-02-16 21:00:51 $
-  Version:   $Revision: 1.16 $
+  Date:      $Date: 2008-05-26 02:39:38 $
+  Version:   $Revision: 1.17 $
 
   Copyright (c) 1993-2002 Ken Martin, Will Schroeder, Bill Lorensen 
   All rights reserved.
