@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: ImageCompareCommand.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-20 12:21:34 $
-  Version:   $Revision: 1.9 $
+  Date:      $Date: 2008-10-06 14:45:24 $
+  Version:   $Revision: 1.11 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -86,7 +86,6 @@ int main(int argc, char **argv)
   command.AddOptionField("baselineImage","filename",MetaCommand::STRING,true);
 
 
-
   command.Parse( argc, argv );
 
 
@@ -203,11 +202,10 @@ int main(int argc, char **argv)
       }
     
     }
-  catch(const itk::ExceptionObject& e)
+  catch(itk::ExceptionObject& e)
     {
     std::cerr << "ITK test driver caught an ITK exception:\n";
-    std::cerr << e.GetFile() << ":" << e.GetLine() << ":\n"
-              << e.GetDescription() << "\n";
+    std::cerr << e << "\n";
     bestBaselineStatus = -1;
     }
   catch(const std::exception& e)
@@ -232,10 +230,10 @@ int RegressionTestImage (const char *testImageFilename, const char *baselineImag
                          int radiusTolerance, int numberOfPixelsTolerance)
 {
   // Use the factory mechanism to read the test and baseline files and convert them to double
-  typedef itk::Image<double,ITK_TEST_DIMENSION_MAX> ImageType;
-  typedef itk::Image<unsigned char,ITK_TEST_DIMENSION_MAX> OutputType;
-  typedef itk::Image<unsigned char,2> DiffOutputType;
-  typedef itk::ImageFileReader<ImageType> ReaderType;
+  typedef itk::Image<double,ITK_TEST_DIMENSION_MAX>         ImageType;
+  typedef itk::Image<unsigned char,ITK_TEST_DIMENSION_MAX>  OutputType;
+  typedef itk::Image<unsigned char,2>                       DiffOutputType;
+  typedef itk::ImageFileReader<ImageType>                   ReaderType;
 
   // Read the baseline file
   ReaderType::Pointer baselineReader = ReaderType::New();
@@ -246,7 +244,7 @@ int RegressionTestImage (const char *testImageFilename, const char *baselineImag
     }
   catch (itk::ExceptionObject& e)
     {
-    std::cerr << "Exception detected while reading " << baselineImageFilename << " : "  << e.GetDescription();
+    std::cerr << "Exception detected while reading " << baselineImageFilename << " : "  << e;
     return 1000;
     }
 
@@ -259,7 +257,7 @@ int RegressionTestImage (const char *testImageFilename, const char *baselineImag
     }
   catch (itk::ExceptionObject& e)
     {
-    std::cerr << "Exception detected while reading " << testImageFilename << " : "  << e.GetDescription() << std::endl;
+    std::cerr << "Exception detected while reading " << testImageFilename << " : "  << e << std::endl;
     return 1000;
     }
 
@@ -315,18 +313,20 @@ int RegressionTestImage (const char *testImageFilename, const char *baselineImag
   
   if (reportErrors)
     {
-    typedef itk::RescaleIntensityImageFilter<ImageType,OutputType> RescaleType;
-    typedef itk::ExtractImageFilter<OutputType,DiffOutputType> ExtractType;
-    typedef itk::ImageFileWriter<DiffOutputType> WriterType;
-    typedef itk::ImageRegion<ITK_TEST_DIMENSION_MAX> RegionType;
+    typedef itk::RescaleIntensityImageFilter<ImageType,OutputType>    RescaleType;
+    typedef itk::ExtractImageFilter<OutputType,DiffOutputType>        ExtractType;
+    typedef itk::ImageFileWriter<DiffOutputType>                      WriterType;
+    typedef itk::ImageRegion<ITK_TEST_DIMENSION_MAX>                  RegionType;
+
     OutputType::IndexType index; index.Fill(0);
     OutputType::SizeType size; size.Fill(0);
 
     RescaleType::Pointer rescale = RescaleType::New();
-      rescale->SetOutputMinimum(itk::NumericTraits<unsigned char>::NonpositiveMin());
-      rescale->SetOutputMaximum(itk::NumericTraits<unsigned char>::max());
-      rescale->SetInput(diff->GetOutput());
-      rescale->UpdateLargestPossibleRegion();
+
+    rescale->SetOutputMinimum(itk::NumericTraits<unsigned char>::NonpositiveMin());
+    rescale->SetOutputMaximum(itk::NumericTraits<unsigned char>::max());
+    rescale->SetInput(diff->GetOutput());
+    rescale->UpdateLargestPossibleRegion();
 
     RegionType region;
     region.SetIndex(index);
@@ -339,8 +339,9 @@ int RegressionTestImage (const char *testImageFilename, const char *baselineImag
     region.SetSize(size);
 
     ExtractType::Pointer extract = ExtractType::New();
-      extract->SetInput(rescale->GetOutput());
-      extract->SetExtractionRegion(region);
+
+    extract->SetInput(rescale->GetOutput());
+    extract->SetExtractionRegion(region);
 
     WriterType::Pointer writer = WriterType::New();
       writer->SetInput(extract->GetOutput());
