@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkIOTests.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-04-03 16:20:36 $
-  Version:   $Revision: 1.60 $
+  Date:      $Date: 2008-06-25 23:11:00 $
+  Version:   $Revision: 1.63 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -41,6 +41,9 @@ void RegisterTests()
   REGISTER_TEST(itkGiplImageIOTest);
   REGISTER_TEST(itkImageSeriesWriterTest);
   REGISTER_TEST(itkImageReadDICOMSeriesWriteTest);
+  REGISTER_TEST(itkImageIOBaseTest);
+  REGISTER_TEST(itkImageIOFileNameExtensionsTests);
+  REGISTER_TEST(itkIOCommonTest);
   REGISTER_TEST(itkIOPrintTest);
   REGISTER_TEST(itkJPEGImageIOTest);
   REGISTER_TEST(itkMatrixImageWriteReadTest);
