@@ -3,8 +3,8 @@
 Program:   Insight Segmentation & Registration Toolkit
 Module:    $RCSfile: itkNiftiImageIOTest.cxx,v $
 Language:  C++
-Date:      $Date: 2008-02-05 14:07:40 $
-Version:   $Revision: 1.19 $
+Date:      $Date: 2008-09-16 17:29:23 $
+Version:   $Revision: 1.20 $
 
 Copyright (c) Insight Software Consortium. All rights reserved.
 See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -155,7 +155,7 @@ static int TestByteSwap(void)
     }
   catch ( itk::ExceptionObject & ex )
     {
-      std::cerr << "Error filling array" << ex.GetDescription() << std::endl;
+      std::cerr << "Error filling array" << ex << std::endl;
       rval= -1;
     }
 
@@ -195,7 +195,7 @@ template <typename T> int MakeNiftiImage(void)
       }
     catch ( itk::ExceptionObject & ex )
       {
-        std::cerr << "Error filling array" << ex.GetDescription() << std::endl;
+        std::cerr << "Error filling array" << ex << std::endl;
         return EXIT_FAILURE;
       }
   }
