@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: metaCommand.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-03-19 20:42:12 $
-  Version:   $Revision: 1.50 $
+  Date:      $Date: 2008-07-18 00:15:39 $
+  Version:   $Revision: 1.53 $
 
   Copyright (c) 2002 Insight Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -18,6 +18,7 @@
 #pragma warning(disable:4702)
 #endif
 
+#include "metaUtils.h"
 #include "metaCommand.h"
 
 #include <stdio.h>
@@ -358,6 +359,35 @@ SetOptionRange(METAIO_STL::string optionName,
   return false;
 }
 
+/** Set the range of an option */
+bool MetaCommand::
+SetOptionEnumerations(METAIO_STL::string optionName,
+                      METAIO_STL::string name,
+                      METAIO_STL::string optionEnums)
+                     
+{
+  OptionVector::iterator it = m_OptionVector.begin();
+  while(it != m_OptionVector.end())
+    {
+    if((*it).name == optionName)
+      {
+      METAIO_STL::vector<Field> & fields = (*it).fields;
+      METAIO_STL::vector<Field>::iterator itField = fields.begin();
+      while(itField != fields.end())
+        {
+        if((*itField).name == name)
+          {
+          (*itField).rangeMin = optionEnums;
+          return true;
+          }
+        itField++;
+        }
+      }
+    it++;
+    }
+  return false;
+}
+
 
 /** Return the value of the option as a boolean */
 bool MetaCommand::
@@ -698,7 +728,22 @@ ListOptions()
                           << METAIO_STREAM::endl;
       METAIO_STREAM::cout << "      Value: " << (*itField).value.c_str() 
                           << METAIO_STREAM::endl;
-      
+      if( (*itField).type == ENUM )
+        {
+        METAIO_STREAM::cout << "      Enum list: " 
+                            << (*itField).rangeMin.c_str()
+                            << METAIO_STREAM::endl;
+        }
+      else
+        {
+        METAIO_STREAM::cout << "      RangeMin: " 
+                            << (*itField).rangeMin.c_str()
+                            << METAIO_STREAM::endl;
+        METAIO_STREAM::cout << "      RangeMax: " 
+                            << (*itField).rangeMax.c_str()
+                            << METAIO_STREAM::endl;
+        }
+        
       if((*itField).externaldata)
         {
         METAIO_STREAM::cout << "      External Data: true" 
@@ -718,6 +763,16 @@ ListOptions()
         {
         METAIO_STREAM::cout << "      Required: false" << METAIO_STREAM::endl;
         }
+
+      if((*itField).userDefined)
+        {
+        METAIO_STREAM::cout << "      User Defined: true" << METAIO_STREAM::endl;
+        }
+      else
+        {
+        METAIO_STREAM::cout << "      User Defined: false" << METAIO_STREAM::endl;
+        }
+
       itField++;
       }
     METAIO_STREAM::cout << METAIO_STREAM::endl;
@@ -839,6 +894,10 @@ void MetaCommand::WriteXMLOptionToCout(METAIO_STL::string optionName,
     {
     optionType = "integer";
     }
+  else if((*itField).type == MetaCommand::ENUM)
+    {
+    optionType = "string-enumeration";
+    }
   else
     {
     optionType = this->TypeToString((*itField).type).c_str();
@@ -890,6 +949,20 @@ void MetaCommand::WriteXMLOptionToCout(METAIO_STL::string optionName,
     {
     METAIO_STREAM::cout << "<channel>output</channel>" << METAIO_STREAM::endl;
     } 
+
+  if((*itField).type == MetaCommand::ENUM)
+    {
+    METAIO_STL::vector< METAIO_STL::string > enumVector;
+    MET_StringToVector< METAIO_STL::string>( (*itField).rangeMin, enumVector );
+    METAIO_STL::vector< METAIO_STL::string >::iterator itenum;
+    itenum = enumVector.begin();
+    while(itenum != enumVector.end() )
+      {
+      METAIO_STREAM::cout << "<element>" << (*itenum).c_str() << "</element>" 
+                          << METAIO_STREAM::endl;
+      ++itenum;
+      }
+    }
       
   // Write out the closing tag 
   METAIO_STREAM::cout << "</" << optionType << ">" << METAIO_STREAM::endl;
@@ -920,7 +993,14 @@ void MetaCommand::ListOptionsSlicerXML()
   ParameterGroupVector::const_iterator itGroup = m_ParameterGroup.begin();
   while(itGroup != m_ParameterGroup.end())
     {
-    METAIO_STREAM::cout << " <parameters>" <<  METAIO_STREAM::endl;
+    if( (*itGroup).advanced == true )
+      {
+      METAIO_STREAM::cout << " <parameters advanced=\"true\">" <<  METAIO_STREAM::endl;
+      }
+    else
+      {
+      METAIO_STREAM::cout << " <parameters>" <<  METAIO_STREAM::endl;
+      }
     METAIO_STREAM::cout << "  <label>" << (*itGroup).name <<  "</label>" <<  METAIO_STREAM::endl;
     
     if((*itGroup).description.size() == 0)
@@ -992,12 +1072,12 @@ GetXML(const char* buffer, const char* desc, unsigned long pos)
 
   METAIO_STL::string buf = buffer;
 
-  long int posb = buf.find(begin,pos);
+  long int posb = static_cast<long int>(buf.find(begin,pos));
   if(posb == -1)
     {
     return "";
     }
-  long int pose = buf.find(end,posb);
+  long int pose = static_cast<long int>(buf.find(end,posb));
   if(pose == -1)
     {
     return "";
@@ -1031,7 +1111,7 @@ ParseXML(const char* buffer)
     unsigned int n = atoi(this->GetXML(buf.c_str(),"nvalues",0).c_str());
 
     // Now check the fields
-    long posF = buf.find("<field>");
+    long posF = static_cast<long>(buf.find("<field>"));
     for(unsigned int i=0;i<n;i++)
       {
       METAIO_STL::string f = this->GetXML(buf.c_str(),"field",posF);
@@ -1066,12 +1146,12 @@ ParseXML(const char* buffer)
         }
 
       option.fields.push_back(field);
-      posF += f.size()+8;
+      posF += static_cast<long>(f.size()+8);
       }
 
     m_OptionVector.push_back(option);
 
-    pos += buf.size()+17;
+    pos += static_cast<long>(buf.size()+17);
     buf = this->GetXML(buffer,"option",pos);
     }
 
@@ -1430,12 +1510,12 @@ ExportGAD(bool dynamic)
              << (*itFields).value.c_str() << "\"/>" << METAIO_STREAM::endl;
 
         METAIO_STL::string datapath = (*itFields).value;
-        long int slash = datapath.find_last_of("/");
+        long int slash = static_cast<long int>(datapath.find_last_of("/"));
         if(slash>0)
           {
           datapath = datapath.substr(slash+1,datapath.size()-slash-1);
           }
-        slash = datapath.find_last_of("\\");
+        slash = static_cast<long int>(datapath.find_last_of("\\"));
         if(slash>0)
           {
           datapath = datapath.substr(slash+1,datapath.size()-slash-1);
@@ -1580,12 +1660,12 @@ ExportGAD(bool dynamic)
         file << "  <parameter name=\"Protocol\" value=\"gsiftp\"/>" 
              << METAIO_STREAM::endl;
         METAIO_STL::string datapath = (*itFields).value;
-        long int slash = datapath.find_last_of("/");
+        long int slash = static_cast<long int>(datapath.find_last_of("/"));
         if(slash>0)
           {
           datapath = datapath.substr(slash+1,datapath.size()-slash-1);
           }
-        slash = datapath.find_last_of("\\");
+        slash = static_cast<long int>(datapath.find_last_of("\\"));
         if(slash>0)
           {
           datapath = datapath.substr(slash+1,datapath.size()-slash-1);
@@ -1619,13 +1699,13 @@ bool MetaCommand::Parse(int argc, char* argv[])
   m_GotXMLFlag = false;
   m_ExecutableName = argv[0];
 
-  long int slash = m_ExecutableName.find_last_of("/");
+  long int slash = static_cast<long int>(m_ExecutableName.find_last_of("/"));
   if(slash>0)
     {
     m_ExecutableName = m_ExecutableName.substr(slash+1,
                                                m_ExecutableName.size()-slash-1);
     }
-  slash = m_ExecutableName.find_last_of("\\");
+  slash = static_cast<long int>(m_ExecutableName.find_last_of("\\"));
   if(slash>0)
     {
     m_ExecutableName = m_ExecutableName.substr(slash+1,
@@ -1831,7 +1911,7 @@ bool MetaCommand::Parse(int argc, char* argv[])
         if((pos >= currentField) && ((*it).tag=="" && (*it).longtag==""))
           {
           currentOption = pos;
-          valuesRemaining = (*it).fields.size();
+          valuesRemaining = static_cast<unsigned int>((*it).fields.size());
           found = true;
           break;
           }
@@ -1877,7 +1957,8 @@ bool MetaCommand::Parse(int argc, char* argv[])
 
       else if(currentOption >=0 && currentOption <(int)(m_OptionVector.size()))
         {
-        unsigned long s = m_OptionVector[currentOption].fields.size();
+        unsigned long s = static_cast<unsigned long>(
+          m_OptionVector[currentOption].fields.size());
 
         // We change the value only if this is not a tag
         if(this->OptionExistsByMinusTag(argv[i]))
@@ -2087,6 +2168,8 @@ METAIO_STL::string MetaCommand::TypeToString(TypeEnumType type)
       return "image";
     case FILE:
       return "file";
+    case ENUM:
+      return "enum";
     default:
       return "not defined";
     }
@@ -2117,6 +2200,22 @@ MetaCommand::TypeEnumType MetaCommand::StringToType(const char* type)
     {
     return FLAG;
     }
+  else if(!strcmp(type,"bool"))
+    {
+    return BOOL;
+    }
+  else if(!strcmp(type,"image"))
+    {
+    return IMAGE;
+    }
+  else if(!strcmp(type,"enum"))
+    {
+    return ENUM;
+    }
+  else if(!strcmp(type,"file"))
+    {
+    return FILE;
+    }
 
   return INT; // by default
 
@@ -2163,7 +2262,8 @@ bool MetaCommand::SetOptionLabel(METAIO_STL::string optionName,
  *  If the group doesn't exist it is automatically created. */
 bool MetaCommand::SetParameterGroup(METAIO_STL::string optionName,
                                     METAIO_STL::string groupName,
-                                    METAIO_STL::string groupDescription
+                                    METAIO_STL::string groupDescription,
+                                    bool advanced
                                     )
 {
   // Check if the group exists
@@ -2203,6 +2303,7 @@ bool MetaCommand::SetParameterGroup(METAIO_STL::string optionName,
     ParameterGroup pgroup;
     pgroup.name = groupName;
     pgroup.description = groupDescription;
+    pgroup.advanced = advanced;
     pgroup.options.push_back(optionName);
     m_ParameterGroup.push_back(pgroup);
     }
