@@ -3,8 +3,8 @@
   Program:   MetaIO
   Module:    $RCSfile: metaImage.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-04-09 20:44:23 $
-  Version:   $Revision: 1.92 $
+  Date:      $Date: 2008-09-18 20:00:17 $
+  Version:   $Revision: 1.99 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -1179,7 +1179,7 @@ CanRead(const char *_headerName) const
         {
         totalFiles *= m_DimSize[i-1];
         }
-      for(i=0; i< totalFiles && !_stream->eof(); i++)
+      for(i=0; i< totalFiles; i++)
         {
         _stream->getline(s, 1024);
         if(!_stream->eof())
@@ -1264,6 +1264,10 @@ CanRead(const char *_headerName) const
           return false;
           }
         }
+      for(i=0; i<nWrds; i++)
+        {
+        delete [] wrds[i++];
+        }
       delete [] dimSize;
       }
     else
@@ -1547,7 +1551,10 @@ ReadStream(int _nDims,
         {
         METAIO_STREAM::cerr << "MetaImage: Read: Cannot open data file"
                             << METAIO_STREAM::endl;
-        m_ReadStream->close();
+        if(m_ReadStream)
+          {
+          m_ReadStream->close();
+          }
         return false;
         }
 
@@ -1891,9 +1898,9 @@ bool MetaImage::WriteROI(int * _indexMin, int * _indexMax,
       tmpWriteStream->seekp(0,METAIO_STREAM::ios::end);  
       size_t endfile = tmpWriteStream->tellp();
       
-      size_t padding = seekpos-endfile;
-      if(padding>0)
+      if(seekpos>endfile)
         {
+        size_t padding = seekpos-endfile;
         unsigned char* zerobytes = new unsigned char[padding];
         memset(zerobytes,0,padding);
         tmpWriteStream->write((const char*)zerobytes,padding);  
@@ -2115,14 +2122,15 @@ bool MetaImage::WriteROI(int * _indexMin, int * _indexMax,
         
         // Add zeros to the region. Maybe this should refer to a function to avoid
         // taking all the memory like we did before.
-        long padding = seekpos-currentPos;
-        
-        unsigned char* zerobytes = new unsigned char[padding];
-        memset(zerobytes,0,padding);
-        MetaImage::M_WriteElementData(m_WriteStream, zerobytes, padding/elementNumberOfBytes);
-        delete [] zerobytes;      
-         
-        currentPos += padding;
+        if(seekpos > currentPos)
+          {
+          size_t padding = seekpos-currentPos;
+          unsigned char* zerobytes = new unsigned char[padding];
+          memset(zerobytes, 0, padding);
+          MetaImage::M_WriteElementData(m_WriteStream, zerobytes, padding/elementNumberOfBytes);
+          delete [] zerobytes;      
+          currentPos += (unsigned long)(padding);
+          } 
         
         // Write the line
         long bytesToWrite = _indexMax[0]-_indexMin[0];
@@ -2590,8 +2598,10 @@ M_ReadElements(METAIO_STREAM::ifstream * _fstream, void * _data,
     {
     // if m_CompressedDataSize is not defined we assume the size of the
     // file is the size of the compressed data
+    bool compressedDataDeterminedFromFile = false;
     if(m_CompressedDataSize==0)
       {
+      compressedDataDeterminedFromFile = true;
       _fstream->seekg(0, METAIO_STREAM::ios::end);
       m_CompressedDataSize = _fstream->tellg();
       _fstream->seekg(0, METAIO_STREAM::ios::beg);
@@ -2602,6 +2612,12 @@ M_ReadElements(METAIO_STREAM::ifstream * _fstream, void * _data,
 
     MET_PerformUncompression(compr, m_CompressedDataSize,
                              (unsigned char *)_data, readSize);
+
+    if (compressedDataDeterminedFromFile)
+      {
+      m_CompressedDataSize = 0;
+      }
+
     delete [] compr;
     }
   else // if not compressed
@@ -2821,7 +2837,7 @@ ReadROI(int * _indexMin, int * _indexMax,
     delete tmpReadStream;
     return false;
     }
-
+    
   if( !this->ReadROIStream(_indexMin, _indexMax,
                            0, tmpReadStream, _readElements, _buffer,subSamplingFactor) )
     {
@@ -2919,12 +2935,19 @@ bool MetaImage::ReadROIStream(int * _indexMin, int * _indexMax,
       int elementSize;
       MET_SizeOfType(m_ElementType, &elementSize);
       elementSize *= m_ElementNumberOfChannels;
-      int totalFiles = 1;
-      for (i = m_NDims; i > fileImageDim; i--)
+      
+      int minV = _indexMin[m_NDims-1];
+      int maxV = minV + (_indexMax[m_NDims-1]-_indexMin[m_NDims-1]);
+      
+      int cnt=0;
+      
+      // Read the previous lines
+      for(i=0;i<minV;i++)
         {
-        totalFiles *= m_DimSize[i-1];
+        _stream->getline(s, 1024);
         }
-      for(i=0; i< totalFiles && !_stream->eof(); i++)
+      
+      for(i=minV; i<=maxV; i+=1)
         {
         _stream->getline(s, 1024);
         if(!_stream->eof())
@@ -2955,11 +2978,28 @@ bool MetaImage::ReadROIStream(int * _indexMin, int * _indexMax,
                                 << METAIO_STREAM::endl;
             continue;
             }
-          M_ReadElementsROI(readStreamTemp,
-                       &(((char *)m_ElementData)[i*m_SubQuantity[fileImageDim]*
+
+        // read only one slice           
+        int * indexMin = new int[m_NDims];
+        int * indexMax = new int[m_NDims];
+        quantity = 1;
+        for(int k = 0;k<m_NDims-1;k++)
+          {
+          quantity *= _indexMax[k]-_indexMin[k]+1; 
+          indexMin[k]= _indexMin[k];
+          indexMax[k]= _indexMax[k];
+          }
+        indexMin[m_NDims-1]=0;
+        indexMax[m_NDims-1]=0;
+        
+        M_ReadElementsROI(readStreamTemp,
+                       &(((char *)m_ElementData)[cnt*quantity*
                                                  elementSize]),
-                       m_SubQuantity[fileImageDim],
-                       _indexMin,_indexMax,subSamplingFactor);
+                       quantity,indexMin,indexMax,
+                       subSamplingFactor,
+                       m_SubQuantity[m_NDims-1]*m_ElementNumberOfChannels*elementSize);               
+                  
+           cnt++;            
           readStreamTemp->close();
           }
         }
@@ -2994,6 +3034,11 @@ bool MetaImage::ReadROIStream(int * _indexMin, int * _indexMax,
         stepV = (int)atof(wrds[3]);
         }
       int cnt = 0;
+      
+      // Uses the _indexMin and _indexMax
+      minV += _indexMin[m_NDims-1];
+      maxV = minV + (_indexMax[m_NDims-1]-_indexMin[m_NDims-1])*stepV;
+            
       for(i=minV; i<=maxV; i += stepV)
         {
         sprintf(s, wrds[0], i);
@@ -3005,6 +3050,8 @@ bool MetaImage::ReadROIStream(int * _indexMin, int * _indexMax,
           {
           strcpy(fName, s);
           }
+          
+          
 #ifdef __sgi
         readStreamTemp->open(fName, METAIO_STREAM::ios::in);
 #else
@@ -3017,13 +3064,30 @@ bool MetaImage::ReadROIStream(int * _indexMin, int * _indexMax,
                               << METAIO_STREAM::endl;
           continue;
           }
-
+        
+        // read only one slice
+        int * indexMin = new int[m_NDims];
+        int * indexMax = new int[m_NDims];
+        quantity = 1;
+        for(int k = 0;k<m_NDims-1;k++)
+          {
+          quantity *= _indexMax[k]-_indexMin[k]+1; 
+          indexMin[k]= _indexMin[k];
+          indexMax[k]= _indexMax[k];
+          }
+        indexMin[m_NDims-1]=0;
+        indexMax[m_NDims-1]=0;
+        
         M_ReadElementsROI(readStreamTemp,
-                       &(((char *)m_ElementData)[cnt*m_SubQuantity[m_NDims-1]*
+                       &(((char *)m_ElementData)[cnt*quantity*
                                                  elementSize]),
-                       m_SubQuantity[m_NDims-1],_indexMin,_indexMax,
-                       subSamplingFactor);
+                       quantity,indexMin,indexMax,
+                       subSamplingFactor,
+                       m_SubQuantity[m_NDims-1]*m_ElementNumberOfChannels*elementSize);               
         cnt++;
+        
+        delete [] indexMin;
+        delete [] indexMax;
 
         readStreamTemp->close();
         }
@@ -3053,10 +3117,13 @@ bool MetaImage::ReadROIStream(int * _indexMin, int * _indexMax,
         {
         METAIO_STREAM::cerr << "MetaImage: ReadROI: Cannot open data file"
                             << METAIO_STREAM::endl;
-        m_ReadStream->close();
+        if(m_ReadStream)
+          {
+          m_ReadStream->close();
+          }
         return false;
-        }
-
+        }     
+     
       M_ReadElementsROI(readStreamTemp, m_ElementData, quantity,
                         _indexMin,_indexMax,subSamplingFactor);
 
@@ -3071,8 +3138,14 @@ bool MetaImage::ReadROIStream(int * _indexMin, int * _indexMax,
 bool MetaImage::
 M_ReadElementsROI(METAIO_STREAM::ifstream * _fstream, void * _data,
                   METAIO_STL::streamsize _dataQuantity,
-                  int* _indexMin, int* _indexMax,unsigned int subSamplingFactor)
+                  int* _indexMin, int* _indexMax,unsigned int subSamplingFactor,
+                  METAIO_STL::streamsize _totalDataQuantity)
 {
+  if(_totalDataQuantity ==0)
+    {
+    _totalDataQuantity = _dataQuantity;
+    }
+   
   for(int dim=0;dim<m_NDims;dim++)
     {
     _indexMin[dim] *= subSamplingFactor;
@@ -3112,7 +3185,7 @@ M_ReadElementsROI(METAIO_STREAM::ifstream * _fstream, void * _data,
       METAIO_STREAM::cout << "MetaImage: M_ReadElementsROI: Skipping header"
                           << METAIO_STREAM::endl;
       }
-    _fstream->seekg(-readSize, METAIO_STREAM::ios::end);
+    _fstream->seekg(-_totalDataQuantity, METAIO_STREAM::ios::end);
     }
 
   unsigned long dataPos = _fstream->tellg();
@@ -3273,6 +3346,7 @@ M_ReadElementsROI(METAIO_STREAM::ifstream * _fstream, void * _data,
         {
         seekpos += m_SubQuantity[i]*m_ElementNumberOfChannels*elementSize*currentIndex[i];
         }
+      
       _fstream->seekg(dataPos+seekpos, METAIO_STREAM::ios::beg);
 
       // Read a line
