@@ -3,8 +3,8 @@
   Program:   MetaIO
   Module:    $RCSfile: metaUtils.h,v $
   Language:  C++
-  Date:      $Date: 2008-04-09 20:04:24 $
-  Version:   $Revision: 1.40 $
+  Date:      $Date: 2008-07-01 11:48:00 $
+  Version:   $Revision: 1.42 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -52,6 +52,9 @@
 
 #include <vector>
 #include <string>
+#include <sstream>
+#include <iostream>
+//#include <iomanip>
 #include <typeinfo>
 #include <string.h>
 
@@ -171,6 +174,33 @@ void MET_SwapByteIfSystemMSB(void* val, MET_ValueEnumType _type);
 METAIO_EXPORT 
 bool MET_StringToWordArray(const char *s, int *n, char ***val);
 
+template <class T>
+void MET_StringToVector( const METAIO_STL::string & s,
+                         METAIO_STL::vector< T > & vec )
+{
+  vec.clear();
+
+  METAIO_STL::string::size_type prevPos = 0;
+  METAIO_STL::string::size_type pos = s.find(",", prevPos);
+  T tVal;
+  while( pos != METAIO_STL::string::npos )
+    {
+    METAIO_STREAM::stringstream ss;
+    METAIO_STL::string tmpString = s.substr( prevPos, (pos-prevPos) );
+    ss << tmpString;
+    ss >> tVal;
+    vec.push_back( tVal );
+
+    prevPos = pos+1;
+    pos = s.find(",", prevPos);
+    }
+  METAIO_STREAM::stringstream ss;
+  METAIO_STL::string tmpString = s.substr( prevPos, (s.size()-prevPos) );
+  ss << tmpString;
+  ss >> tVal;
+  vec.push_back( tVal );
+}
+
 METAIO_EXPORT 
 bool MET_StringToType(const char *_str, MET_ValueEnumType *_type);
 
@@ -326,7 +356,7 @@ bool MET_InitWriteField(MET_FieldRecordType * _mf,
   _mf->name[254] = '\0';
   _mf->type = _type;
   _mf->defined = true;
-  _mf->length = _length;
+  _mf->length = static_cast<int>(_length);
   _mf->dependsOn = -1;
   _mf->required = false;
   _mf->terminateRead = false;
@@ -400,7 +430,6 @@ METAIO_STL::string MET_ReadType(METAIO_STREAM::istream & _fp);
 METAIO_EXPORT 
 char * MET_ReadSubType(METAIO_STREAM::istream & _fp);
 
-
 #if (METAIO_USE_NAMESPACE)
 };
 #endif
