@@ -3,8 +3,8 @@
   Program:   gdcm
   Module:    $RCSfile: gdcmFile.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-04-11 16:50:17 $
-  Version:   $Revision: 1.22 $
+  Date:      $Date: 2008-05-14 12:25:32 $
+  Version:   $Revision: 1.24 $
                                                                                 
   Copyright (c) CREATIS (Centre de Recherche et d'Applications en Traitement de
   l'Image). All rights reserved. See Doc/License.txt or
@@ -173,7 +173,7 @@ bool File::DoTheLoadingJob( )
  
    // Image Location
    const std::string &imgLocation = GetEntryValue(0x0028, 0x0200);
-   if ( imgLocation == GDCM_UNFOUND )
+   if ( imgLocation == GDCM_UNFOUND || imgLocation == GDCM_BINLOADED )
    {
       // default value
       GrPixel = 0x7fe0;
@@ -1372,7 +1372,7 @@ double File::GetRescaleIntercept()
 
 /**
  *\brief   gets the info from 0028,1053 : Rescale Slope
- * @return Rescale Slope. defaulted to 1.0 is not found or empty
+ * @return Rescale Slope. defaulted to 1.0 is not found, == 0.0 or empty
  */
 double File::GetRescaleSlope()
 {
@@ -1392,6 +1392,11 @@ double File::GetRescaleSlope()
          gdcmWarningMacro( "Rescale Slope (0028,1053) is empty.");
       }
    }
+   if( resSlope == 0. )
+     {
+     gdcmWarningMacro( "No such thing as a slope of 0.0. Defaulting to 1.0 value" );
+     return 1.0;
+     }
 
    return resSlope;
 }
