@@ -4,8 +4,8 @@
   Module:    $RCSfile: gdcmFileHelper.cxx,v $
   Language:  C++
 
-  Date:      $Date: 2007-12-11 11:19:48 $
-  Version:   $Revision: 1.21 $
+  Date:      $Date: 2008-05-30 11:37:00 $
+  Version:   $Revision: 1.26 $
                                                                                 
   Copyright (c) CREATIS (Centre de Recherche et d'Applications en Traitement de
   l'Image). All rights reserved. See Doc/License.txt or
@@ -1440,8 +1440,8 @@ void FileHelper::CheckMandatoryElements()
    // just to remember : 'official' 0002 group
    if ( WriteType != ACR && WriteType != ACR_LIBIDO )
    {
-     // Group 000002 (Meta Elements) already pushed out
-  
+   // Group 000002 (Meta Elements) already pushed out
+
    //0002 0000 UL 1 Meta Group Length
    //0002 0001 OB 1 File Meta Information Version
    //0002 0002 UI 1 Media Storage SOP Class UID
@@ -1452,7 +1452,7 @@ void FileHelper::CheckMandatoryElements()
    //0002 0016 AE 1 Source Application Entity Title
    //0002 0100 UI 1 Private Information Creator
    //0002 0102 OB 1 Private Information
-  
+
    // Push out 'ACR-NEMA-special' entries, if any
    Archive->Push(0x0008,0x0001); // Length to End
    Archive->Push(0x0008,0x0010); // Recognition Code
@@ -1461,13 +1461,13 @@ void FileHelper::CheckMandatoryElements()
    // Create them if not found
    // Always modify the value
    // Push the entries to the archive.
-      CopyMandatoryEntry(0x0002,0x0000,"0");
+   CopyMandatoryEntry(0x0002,0x0000,"0");
 
-      BinEntry *e_0002_0001 = CopyBinEntry(0x0002,0x0001, "OB");
-      e_0002_0001->SetBinArea(const_cast<uint8_t*>(Util::GetFileMetaInformationVersion()),
-                               false);
-      e_0002_0001->SetLength(2);
-      Archive->Push(e_0002_0001);
+   BinEntry *e_0002_0001 = CopyBinEntry(0x0002,0x0001, "OB");
+   e_0002_0001->SetBinArea(const_cast<uint8_t*>(Util::GetFileMetaInformationVersion()),
+     false);
+   e_0002_0001->SetLength(2);
+   Archive->Push(e_0002_0001);
 
    // 'Media Storage SOP Class UID'  --> [Secondary Capture Image Storage]
    // Only if not specified by user, to let people create DERIVED images
@@ -1481,12 +1481,13 @@ void FileHelper::CheckMandatoryElements()
    CopyMandatoryEntry(0x0002,0x0003,sop);
 
    // 'Implementation Class UID'
-      CopyMandatoryEntry(0x0002,0x0012,Util::CreateUniqueUID());
+   // $ echo "gdcm" | od -b
+   CopyMandatoryEntry(0x0002,0x0012,"147.144.143.155");
 
    // 'Implementation Version Name'
-      std::string version = "ITK/GDCM ";
-      version += Util::GetVersion();
-      CopyMandatoryEntry(0x0002,0x0013,version);
+   std::string version = "ITK/GDCM ";
+   version += Util::GetVersion();
+   CopyMandatoryEntry(0x0002,0x0013,version);
    }
 
    // Push out 'LibIDO-special' entries, if any
@@ -1504,7 +1505,7 @@ void FileHelper::CheckMandatoryElements()
 
    // Check if user wasn't drunk ;-)
 
-   itksys_ios::ostringstream s;
+   itksys_ios::ostringstream os;
    // check 'Bits Allocated' vs decent values
    int nbBitsAllocated = FileInternal->GetBitsAllocated();
    if ( (nbBitsAllocated == 0 || nbBitsAllocated > 32)
@@ -1519,9 +1520,9 @@ void FileHelper::CheckMandatoryElements()
    int nbBitsStored = FileInternal->GetBitsStored();
    if ( nbBitsStored == 0 || nbBitsStored > nbBitsAllocated )
    {
-      s.str("");
-      s << nbBitsAllocated;
-      CopyMandatoryEntry(0x0028,0x0101,s.str());
+      os.str("");
+      os << nbBitsAllocated;
+      CopyMandatoryEntry(0x0028,0x0101,os.str());
       gdcmWarningMacro("(0028,0101) changed from "
                        << nbBitsStored << " to " << nbBitsAllocated
                        << " for consistency purpose" );
@@ -1533,9 +1534,9 @@ void FileHelper::CheckMandatoryElements()
         highBitPosition > nbBitsAllocated-1 ||
         highBitPosition < nbBitsStored-1  )
    {
-      s.str("");
-      s << nbBitsStored - 1; 
-      CopyMandatoryEntry(0x0028,0x0102,s.str());
+      os.str("");
+      os << nbBitsStored - 1; 
+      CopyMandatoryEntry(0x0028,0x0102,os.str());
       gdcmWarningMacro("(0028,0102) changed from "
                        << highBitPosition << " to " << nbBitsAllocated-1
                        << " for consistency purpose");
@@ -1573,6 +1574,10 @@ void FileHelper::CheckMandatoryElements()
    ValEntry *e_0008_0016 = FileInternal->GetValEntry(0x0008, 0x0016);
    if ( e_0008_0016 )
    {
+      // Make sure 0008,0016 & 0002,0002 are always consistant whatever user says...
+      ValEntry *e_0002_0002 = FileInternal->GetValEntry(0x0002, 0x0002);
+      e_0002_0002->SetValue( e_0008_0016->GetValue() );
+
       // Create 'Source Image Sequence' SeqEntry
       SeqEntry *sis = new SeqEntry (
             Global::GetDicts()->GetDefaultPubDict()->GetEntry(0x0008, 0x2112) );
@@ -1586,6 +1591,11 @@ void FileHelper::CheckMandatoryElements()
 
       // create 'Referenced SOP Instance UID'
       ValEntry *e_0008_0018 = FileInternal->GetValEntry(0x0008, 0x0018);
+
+      // Make sure 0008,0018 & 0002,0003 are always consistant whatever user says...
+      ValEntry *e_0002_0003 = FileInternal->GetValEntry(0x0002, 0x0003);
+      e_0002_0003->SetValue( e_0008_0018->GetValue() );
+
       ValEntry *e_0008_1155 = new ValEntry(
             Global::GetDicts()->GetDefaultPubDict()->GetEntry(0x0008, 0x1155) );
       e_0008_1155->SetValue( e_0008_0018->GetValue());
@@ -1596,7 +1606,40 @@ void FileHelper::CheckMandatoryElements()
       Archive->Push(sis);
 
       // 'Image Type' (The written image is no longer an 'ORIGINAL' one)
-      CopyMandatoryEntry(0x0008,0x0008,"DERIVED\\PRIMARY");
+      ValEntry *e_0008_0008 = FileInternal->GetValEntry(0x0008, 0x0008);
+      std::string imagetype = "DERIVED\\PRIMARY";
+      // Make sure to preserved information from element 0008,0008, simply replace
+      // comp #1 of Image Type with 'DERIVED', as gdcm is always deriving image
+      if( e_0008_0008 )
+        {
+        std::string s = e_0008_0008->GetValue();
+        if( !s.empty() )
+          {
+          std::vector<std::string> tokens;
+          gdcm::Util::Tokenize( s, tokens, "\\");
+          // Make sure we can find at least 2 names...
+          if( tokens.size() >= 2 )
+            {
+            itksys_ios::ostringstream os2;
+            for( std::vector<std::string>::const_iterator it = tokens.begin();
+              it != tokens.end(); ++it)
+              {
+              if( it == tokens.begin() )
+                {
+                // Mark it DERIVED
+                os2 << "DERIVED";
+                }
+              else
+                {
+                os2 << "\\";
+                os2 << *it;
+                }
+              }
+            imagetype = os.str();
+            }
+          }
+        }
+      CopyMandatoryEntry(0x0008,0x0008,imagetype);
    }
    else
    {
@@ -1607,8 +1650,11 @@ void FileHelper::CheckMandatoryElements()
          Global::GetDicts()->GetDefaultPubDict()->GetEntry(0x0008, 0x0016) );
        e_0008_0016 ->SetValue( e_0002_0002->GetValue() );
        ValEntry *e_0008_0018 = FileInternal->GetValEntry(0x0008, 0x0018);
-       e_0008_0018->SetValue(
-         FileInternal->GetValEntry(0x0002,0x0003)->GetValue() );
+       if( e_0008_0018 )
+         {
+         e_0008_0018->SetValue(
+           FileInternal->GetValEntry(0x0002,0x0003)->GetValue() );
+         }
        Archive->Push(e_0008_0016);
        }
      else
