@@ -3,8 +3,8 @@
   Program:   gdcm
   Module:    $RCSfile: gdcmPixelReadConvert.cxx,v $
   Language:  C++
-  Date:      $Date: 2006-09-05 22:07:20 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date: 2008-05-28 11:26:41 $
+  Version:   $Revision: 1.11 $
                                                                                 
   Copyright (c) CREATIS (Centre de Recherche et d'Applications en Traitement de
   l'Image). All rights reserved. See Doc/License.txt or
@@ -44,7 +44,7 @@ bool gdcm_read_JPEG2000_file (void* raw,
 //-----------------------------------------------------------------------------
 // Constructor / Destructor
 /// Constructor
-PixelReadConvert::PixelReadConvert() 
+PixelReadConvert::PixelReadConvert()
 {
    RGB          = 0;
    RGBSize      = 0;
@@ -144,6 +144,11 @@ void PixelReadConvert::GrabInformationsFromFile( File *file )
    IsJPEGLossless  = Global::GetTS()->IsJPEGLossless(ts);
    IsRLELossless   = Global::GetTS()->IsRLELossless(ts);
 
+      IsPrivateGETransferSyntax = 
+                ( Global::GetTS()->GetSpecialTransferSyntax(ts) == TS::ImplicitVRBigEndianPrivateGE );
+
+
+
    PixelOffset     = file->GetPixelOffset();
    PixelDataLength = file->GetPixelAreaLength();
    RLEInfo         = file->GetRLEInfo();
@@ -552,7 +557,7 @@ bool PixelReadConvert::ReadAndDecompressJPEGFile( std::ifstream *fp )
 //    if ( ! gdcm_read_JPEGLS_file( fp,Raw ) )
          return false;
    }
-   else
+   else if( JPEGInfo )
    {
      // make sure this is the right JPEG compression
      assert( !IsJPEGLS || !IsJPEG2000 );
@@ -563,6 +568,8 @@ bool PixelReadConvert::ReadAndDecompressJPEGFile( std::ifstream *fp )
      JPEGInfo->DecompressFromFile(fp, Raw, BitsStored, numberBytes, length );
      return true;
    }
+   //else (not sure how get there...), must be one of those crazy DICOM file
+   return false;
 }
 
 /**
@@ -1050,7 +1057,7 @@ bool PixelReadConvert::ConvertReArrangeBits() throw ( FormatError )
             // nmask : to propagate sign bit on negative values
             int16_t nmask = (int16_t)0x8000;  
             nmask = nmask >> ( BitsAllocated - BitsStored - 1 );
- 
+
             for(int i = 0; i<l; i++)
             {
                *deb = *deb >> (BitsStored - HighBitPosition - 1);
@@ -1152,9 +1159,9 @@ void PixelReadConvert::ConvertYcBcRPlanesToRGBPixels()
   // except for the few patches of color on the image.
   // On such images, RLE achieves a compression ratio that is much better 
   // than the compression ratio on an equivalent RGB image. 
- 
+
    gdcmWarningMacro("--> ConvertYcBcRPlanesToRGBPixels");
-   
+
    uint8_t *localRaw = Raw;
    uint8_t *copyRaw = new uint8_t[ RawSize ];
    memmove( copyRaw, localRaw, RawSize );
