@@ -3,8 +3,8 @@
   Program:   gdcm
   Module:    $RCSfile: gdcmUtil.h,v $
   Language:  C++
-  Date:      $Date: 2007-02-22 00:16:19 $
-  Version:   $Revision: 1.9 $
+  Date:      $Date: 2008-05-19 07:14:39 $
+  Version:   $Revision: 1.12 $
                                                                                 
   Copyright (c) CREATIS (Centre de Recherche et d'Applications en Traitement de
   l'Image). All rights reserved. See Doc/License.txt or
@@ -76,14 +76,19 @@ public:
    static void SetFileMetaInformationVersion( uint16_t fmiv )
                      { FileMetaInformationVersion = (uint8_t *)&fmiv; }
 
+protected:
+   static const char * CreateUniqueUID2(const std::string &root = "");
 private:
+   static bool   GenerateUUID(unsigned char *uuid_data);
+   static size_t EncodeBytes(char *out, const unsigned char *data, int size);
+   static bool IsValid(const char *uid_);
    static std::string GetIPAddress(); //Do not expose this method
 
    static std::string RootUID;
    static const std::string GDCM_UID;
    static uint8_t *FileMetaInformationVersion;
    static const uint16_t FMIV;
-   static std::string GDCM_MAC_ADRESS;
+   static std::string GDCM_MAC_ADDRESS;
 };
 
 GDCM_EXPORT std::ostream &binary_write(std::ostream &os, const uint16_t &val);
